module humfun2


   private
   public :: humcap_test,humcap_myopic

contains
 
!-------------------------------------------------------------------------
!-------------------------------------------------------------------------
!-------------------------------------------------------------------------

subroutine humcap_test(n,xv,fun)
use mod_types
use riskyparam
use utils
use MersenneTwister_mod
    
    
type(randomNumberSequence) :: random_humfun

integer :: n,jj,indmat(min(nocc,nper),nper),permat(nocc),ii,maxi,kk,nn,hiter,&
            last,iflag,lastocc,maxgit,siter,ncount,seedh
            
real(dp) :: xv(n),fun, payoff(nocc),totmat(nocc),paymat(min(nocc,nper),nper),&
             sorted(nocc),probs(min(nocc,nper)-1),dprobs(min(nocc,nper)-1),&
             cprobs(min(nocc,nper)),occvec(nocc),dprobs2(min(nocc,nper)-1),&
             gittvec(nocc),htol,eta,gittfunval,gittval,xguess,update,x1,x2,& 
             laborearn(mcdraws,ntdraws),laborocc(mcdraws,ntdraws),sorted2(nocc)
real(dp) :: cost,net,uvar1,uvar2,dnordf,dlndf,uvar3

if (minval(xv).le.1.0d-16.or.exp(abvec(1))*xv(1).gt.1000.00d+00&
    .or.exp(abvec(2))*xv(2).gt.1000.00d+00.or.exp(abvec(3))*&
    xv(3).gt.1000.00d+00.or.isnan(xv(1)) ) then

    fun = 1.0d+10
 
else
    do jj=1,nocc
        payoff(jj) = 0.0d+00
        totmat(jj) = 0.0d+00
    enddo
     
    !---------------------------------------------------------------------------
    ! Store "first-time" payoffs in each occupation
    !---------------------------------------------------------------------------
    
    do jj=1,nocc 
    
        payoff(jj) =((xv(1)**rhomat(jj))*mumat(jj,1) +&
                    (xv(2)**rhomat(jj))*mumat(jj,2) + &
                    (xv(3)**rhomat(jj))*(1.0d+00-mumat(jj,1)-&
                    mumat(jj,2)))**(1.0d+00/rhomat(jj))
    enddo 
    
    occvec = exp(sigmamat)
    
    do kk=1,nocc
      totmat(kk) = occvec(kk)*payoff(kk)
    enddo
    
    !---------------------------------------------------------------------------
    ! First compute Gittins index for all occupations using zero-finding routine
    !---------------------------------------------------------------------------
    
    do jj=1,nocc
    
        mgit = dlog(totmat(jj))
        sgit = sigmaocc_vec(jj)
        
        income = totmat(jj)
        
        xguess= 0.1_dp
        
        call Mueller(xguess, 1d-2,1.0d-6,100,gittval,siter)
        
        if (gittval.lt.0.0d+00) then
            write(*,*) 'no conv gittins',xv
            call Mueller(xguess, 1.0d-5,1.0d-6,siter,gittval,siter)
        endif
        
        gittvec(jj) = gittval
    
    
    enddo ! end loop computing gittins index
    
    do kk=1,nocc
        permat(kk) = kk
    enddo
    
    !---------------------------------------------------------------------------
    ! Now sort all the gittins indices in descending order
    !-----------------------------------------------------------------------
    
    call d_mrgref(-gittvec,permat,nocc)
    do kk=1,nocc
        sorted(kk) = gittvec(permat(kk))
    enddo
    
    !---------------------------------------------------------------------------
    ! Do simulation of earnings taking ranking of Gittins 
    ! index as the basis for the decision rule.
    !---------------------------------------------------------------------------
    
    laborocc(:,1) = permat(1)
    laborearn(:,1) = totmat(permat(1))
      
    maxgit = 1 
    
    seedh = niter2*nthread2*nthread2+12374 
    random_humfun = new_RandomNumberSequence(seed = seedh )
    
    do hiter=1,mcdraws ! mcdraws
      
         sorted2 = sorted
         
         jj=1 ! start from best occupation
         do ncount=2,ntdraws
         
            uvar3 = getRandomReal(random_humfun)
            
            if (uvar3.lt.psi) then  ! learning takes place 
                x1 = getRandomReal(random_humfun)
                x2 = getRandomReal(random_humfun)
                uvar1 = exp(r8_normal_01(x1,x2)* &
                    sigmaocc_vec( permat(jj) ) - &
                    0.5_dp*sigmaocc_vec(permat(jj))**2.0_dp )
                   
                sorted2(jj) = (uvar1 * totmat(permat(jj))) *(gamma/(one-betam*gamma)) 
                
                maxgit = int(maxelem(sorted2(:),nocc)) !compute maximum gittins
            
                if (maxgit.le.jj.or.jj.eq.nocc) then ! you found the best match
                
                    exit
                
                else ! keep trying occupations sequentially
                
                    jj= jj + 1
                    
                    laborocc(hiter,ncount) = permat(jj)
                    laborearn(hiter,ncount) =  totmat(permat(jj))
                
                    if (jj.ge.nocc) then
                        exit
                    endif
                
                endif
            
            else ! no learning
             
                laborocc(hiter,ncount) = laborocc(hiter,ncount-1)
                laborearn(hiter,ncount) = laborearn(hiter,ncount-1)
            
            endif
          
         enddo ! end count loop
         
         laborocc(hiter,ncount:ntdraws) = permat(maxgit)
          
         ii=1
         do siter = ncount,ntdraws
            laborearn(hiter,siter) =  sorted2(maxgit)*&
                ((one-gamma*betam)/gamma)*(gamma**real(ii))
            ii=ii+1
         enddo
         
    
    enddo ! end hiter loop
    
    !------------------------------
    ! Use laborearn matrix to compute expected 
    ! value of labor market (appropriately discounted
    !------------------------------
    
    fun = -(exp(abvec(1)))*xv(1)**2.0_dp-&
           (exp(abvec(2)))*xv(2)**2.0_dp-&
           (exp(abvec(3)))*xv(3)**2.0_dp
     
    do jj=1,ntdraws
    fun = fun + (betam**real(jj))*(sum(laborearn(:,jj))/real(mcdraws))
    enddo
    
    
    fun = -fun 
    
    uvar1 = getRandomReal(random_humfun)
    maxi = int(floor(uvar1*mcdraws)+1)
    
    
    evec(1:nper)= laborearn(maxi,1:nper) 
    evec(nper+1) = laborearn(maxi,ntdraws)
    ivec(1:nper) = laborocc(maxi,1:nper) 
    ivec(nper+1) = laborocc(maxi,ntdraws)
    
    laborocc2 = laborocc(:,1:nocc+1)
    laborearn2 = laborearn(:,1:nocc+1)
 
endif

end subroutine


  
!-------------------------------------------------------------------------
!-------------------------------------------------------------------------
!-------------------------------------------------------------------------

subroutine humcap_myopic(n,xv,fun)
use mod_types
use riskyparam
use utils


implicit none

integer :: n,jj,indmat(min(nocc,nper),nper),permat(nocc),ii,maxi,kk,nn,hiter,&
           last,iflag,lastocc,maxgit,siter 
           
real(dp) :: xv(n),fun, payoff(nocc),totmat(nocc),paymat(min(nocc,nper),nper),&
            sorted(nocc),probs(min(nocc,nper)-1),dprobs(min(nocc,nper)-1),&
            cprobs(min(nocc,nper)),occvec(nocc),dprobs2(min(nocc,nper)-1),&
            gittvec(nocc),htol,eta,gittfunval,gittval,xguess,update,& 
            laborearn(mcdraws,nocc+1),laborocc(mcdraws,nocc+1),sorted2(nocc)

real(dp) :: cost,count,net,uvar1,uvar2,intval,dnordf,intlo,inthi,tol1,tol2
integer, parameter :: qlimit =1000, qlenw = 6000
real(dp) :: qwork(qlenw),qiwork(qlimit)
   
 

    if (minval(xv).le.0.0d+00.or.exp(abvec(1))* &
        xv(1).gt.1000.00d+00.or.exp(abvec(2))* &
        xv(2).gt.1000.00d+00.or.exp(abvec(3))* &
        xv(3).gt.1000.00d+00) then
    
        fun = 1.0d+10
    
    else
        do jj=1,nocc
            payoff(jj) = 0.0d+00
            totmat(jj) = 0.0d+00
        enddo
        
        do jj=1,nocc
        
            payoff(jj) =((xv(1)**rhomat(jj))*mumat(jj,1) + &
                         (xv(2)**rhomat(jj))*mumat(jj,2) + &
                         (xv(3)**rhomat(jj))*(1.0d+00-&
                         mumat(jj,1)-mumat(jj,2)))**(1.0d+00/rhomat(jj))
        enddo
        
        occvec = exp(sigmamat)
        
        do kk=1,nocc
            totmat(kk) = occvec(kk)*payoff(kk)
        enddo
        
        fun = -(exp(abvec(1)))*xv(1)**2.0_dp-&
               (exp(abvec(2)))*xv(2)**2.0_dp-&
               (exp(abvec(3)))*xv(3)**2.0_dp
         
        fun = fun + betam*totmat(mind)+&
        betam*(betam*gamma/(1.0_dp-betam*gamma))*totmat(mind)
         
         
        fun = -fun
        
        ivec = mind
        evec(1) = totmat(mind)
        do kk=2,size(evec)
            evec(kk) = evec(kk-1)*gamma
        enddo
    
    endif

end subroutine

end module humfun2
