!  risky_noestim.f90
!
!  FUNCTIONS:
!  risky_noestim - Entry point of console application.
!C:\Program Files (x86)\VNI\imsl\fnl600\Intel64\include\dll

!****************************************************************************
!
!  PROGRAM: risky_noestim
!
!  PURPOSE:  Entry point for the console application.
!
!****************************************************************************

program redohk

use mod_types
use modfun
use riskyparam
use omp_lib
use MersenneTwister_mod
use utils

implicit none

real(dp) :: calibx(nvar),bigfunval,subplx,&
            gradval(nmom),jacmat(nmom,nvar),&
            diff,grad2(nmom)

integer :: ii,jj,siter

! Optimization parameters
real(dp) :: step(nvar),stopcr,diagvar(nvar),simp
integer :: iprint,maxiter,nloop,iquad,iflag
real(dp) :: work(2*nvar+5*(5+4)+1)
integer :: iwork(nvar+nvar/2)

estim_flag = 2 ! estimation flag 0: estimation with identity weighting
               ! matrix, 1: optimal weighting matrix
               ! 2: Do not estimate. Just simulate larger model with
               ! estimated parameter vector.

! The code loops through the following 3 values for the variable exp1 
         ! =0 baseline estimation
         ! =1 No uncertainty
         ! =2 specialization to best industry.

ces_flag = 0 ! 0: Cobb-Douglas, 1: CES with rho = -1.15

if (estim_flag == 0) then
    open(unit=9, file='initguess_unweighted.txt')
    do ii=1,nvar
    read(9,*) (calibx(ii))
    enddo 
    close(unit=9)

    do ii=1,nmom
            dataweight(ii) = 1.0d+00 
    enddo

else

    open(unit=10, file='dataweights.txt')
    do ii=1,nmom
            dataweight(ii) = 1.0d+00
            read(10,*) dataweight(ii)
    enddo 
    close(unit=10)

    if (ces_flag==0) then 
    
        open(unit=9, file='initguess_weighted.txt')
        do ii=1,nvar
                read(9,*) (calibx(ii))
        enddo 
        close(unit=9)

    else
   
        close(unit=10)
        open(unit=9, file='initguess_weighted_ces.txt')
        do ii=1,nvar
                read(9,*) (calibx(ii))
        enddo 
        close(unit=9)

    endif

endif

    open(unit=11, file='emptargets.txt')
    do ii=1,nmom
        read(11,*) (data_target(ii,1))
    enddo   

    write(*,*) 'PARAMETER VECTOR: ', calibx
    2768  format (47(f15.5)) 

if (estim_flag==2) then 
    do exp1 = 0,2
    bigfunval = bigfun(nvar,calibx)
    enddo 
    stop
else
    
! ______________________________________________________________________
! Estimation code (run on smaller version) Reduce nagent and ntdraws in
! riskyparam.f90
! ______________________________________________________________________

    diagvar = 0.05d+00
    bigfunval = subplx(bigfun,nvar,0.0001,500,00,diagvar,calibx,bigfunval,maxiter,work,iwork,iflag) 
    stop
    
    ! start computing jacobian
    call bigfunjac(nmom,nvar,calibx,gradval)
    open( UNIT=3, FILE='jacobian.txt')
    do siter=1,nmom
    write (3,2021) gradval(siter)
    enddo
    close(unit=3)
    jacmat = 0.0d+00
    
    diff=5.0d-4
    
    ! main jacobian loop

    do ii=1,nvar

        calibx(ii) = calibx(ii) + diff
        grad2 =0.0d+00

      call bigfunjac(nmom,nvar,calibx,grad2)

        calibx(ii) = calibx(ii) - 2.0*diff

       call bigfunjac(nmom,nvar,calibx,gradval)

       do jj=1,nmom
       jacmat(jj,ii) = (grad2(jj) -gradval(jj))/(2.0*diff)
       write(*,*) ii,jj,grad2(jj),gradval(jj),jacmat(jj,ii)
       enddo
      
        calibx(ii) = calibx(ii) +  diff

    enddo

    write(*,*) calibx
   open( UNIT=3, FILE='jacobian.txt')
 
 
 do siter=1,nmom
 write (3,2021) jacmat(siter,:)
  enddo
 close(unit=3)

 2021 format (47(f15.5))

 endif

end program redohk
