module utils 
use riskyparam

 
contains


double precision function maxelem(x,nb)
    use mod_types
    integer :: nb
    real(dp) :: n1,acc, xmax, x(nb)
        
    xmax=maxval(x)
    
    acc=0
    n1=1
    do while (acc==0)
     
    if (xmax==x(n1)) then
    acc=1
    endif
    
    n1=n1+1
    if (n1>nb) then
    acc=1
    endif
    enddo
    maxelem=n1-1

end function maxelem

double precision function aver(vector,nx)

    use mod_types
    integer :: nx, nxx
    real(dp) :: vector(nx)
    
    aver=0
    do nxx=1,nx
    aver=aver+vector(nxx)
    enddo
    
    
    
    aver=aver/real(nx)

end function aver

double precision function stdev(vector,nx)

    use mod_types
    integer :: nx, nxx
    real(dp) :: vector(nx),vector2(nx), z1, z2
    do nxx=1,nx
    vector2(nxx) = (vector(nxx))**2.0D+00
    enddo
    
    z1 = aver(vector2,nx)
    z2 = aver(vector,nx)
    
    if (z1.lt.z2**2.0_dp) then
    write(*,*) 'poblema stdev'
    endif
    
    stdev = sqrt(z1-z2**2.0_dp)

end function stdev

double precision function corrcoef(vector1,vector2,nx)

    use mod_types
    integer :: nx, nxx
    real(dp) :: vector1(nx),vector2(nx), z1, z2 
    
    z1 = 0.0d+000
    do nxx=1,nx
    z1 = z1 + vector1(nxx)*vector2(nxx)
    enddo
    
    z1 = real(z1/nx)
    
    corrcoef = (z1-aver(vector1,nx)*aver(vector2,nx))/(stdev(vector1,nx)*stdev(vector2,nx))

    
end function corrcoef

   !function to compute the lognormal pdf
double precision function lognpdf(x)

   use riskyparam
   use mod_types
   
   real(dp) :: x
  
   lognpdf = one/(x*sgit*sqrt(2.0_dp*pi))*&
       exp(-0.5_dp* ( (dlog(x)-mgit)**2.0_dp /sgit**2.0_dp ) )
   
end function lognpdf
   
   !---------------------------------------------------------------------------
   !---------------------------------------------------------------------------
   !---------------------------------------------------------------------------
    
   
! function to compute the x*lognormal pdf (x) 
! function (needed to compute gittins below)
   
double precision function xlognpdf(x)
   use riskyparam
   use mod_types
   
   real(dp) :: x
   
   ! xlognpdf = x*lognpdf
   xlognpdf = one/(sgit*sqrt(2.0_dp*pi))*&
              exp(-0.5_dp* ( (dlog(x)-mgit)**2.0_dp /sgit**2.0_dp ) )
   
end function xlognpdf
   
!---------------------------------------------------------------------------
!---------------------------------------------------------------------------
!---------------------------------------------------------------------------

!function to compute the reservation value (Gittins index for a particular occupation
! gets input from humfun2 from where the zero-finding routine is called.

double precision function gittins(yy)

   use riskyparam
   use mod_types
   
    real(dp) :: yy,int1,int2,htol,tolint1,tolint2,lo1,hi1,lo2,hi2
    integer :: intflag,siter
    integer, parameter :: limit =1000, lenw = 6000
    real(dp) :: work(lenw),iwork(limit),bwiggle
    bwiggle = betam*gamma
     
    if (yy.lt.0.0d+00) then
         gittins=10000.0d+00
    else
     
        ! define tolerance 
        tolint1 = 1.0d-12
        tolint2 = 1.0d-12

        ! Define integration limits 
        lo1 = exp(mgit - 3.0_dp*sgit)
        hi1 = yy *(one-bwiggle)/gamma
        call dqag(lognpdf,lo1, hi1,tolint1,tolint2,&
            5,int1,htol,siter,intflag,limit,lenw,last,iwork,work)
        if (intflag.eq.1) then
            print *,'1 int:', niter2, lo1, hi1,mgit,sgit
            stop
        endif 
        
        ! Define integration limits 
        lo2 = yy *(one-bwiggle)/gamma
        hi2 = exp(mgit + 3.0_dp*sgit)
        call dqag(xlognpdf, lo2, hi2,tolint1,tolint2,&
            5,int2,htol,siter,intflag,limit,lenw,last,iwork,work)
        if (intflag.eq.1) then
            print *,'2 int:', lo2, hi2
            stop
        endif    
   
        gittins = yy-(1.0-psi)*(income+yy*(1.0-betam))-&
            psi*(income+(bwiggle/(one-bwiggle))* &
            (  (yy *(one-bwiggle)/gamma)*int1 + int2))

   endif

end function gittins
 
!***********************************************
!*         Mueller's method subroutine         *
!* ------------------------------------------- *
!* This routine iteratively seeks the root of  *
!* a function Y(x) by fitting a parabola to    *
!* three points and calculating the nearest    *
!* root as described in Becket and Hurt, nume- *
!* rical calculations and algorithms.          *
!* writeS:                                     *
!* The routine requires an initial guess, x0,  *
!* a bound on the error on this guess, d and a *
!* convergence criteria, e. Also required is a *
!* limit on the number of iterations, n.       *
!* OUTPUTS:                                    *
!* The routine returns the value of the root   *
!* found, x and the number of iterations per-  *
!* formed, k.                                  *
!***********************************************
Subroutine Mueller(x0,d,e,n,x,k) 
  !Labels: 100, 200
  integer k,n
  real*8  x0,d,e,x
  real*8  a1,b,c1,d1,e1,e2,e3,x1,x2,x3,xl,xl1
  ! Set up the three evaluation points
  k=1; x3=x0; x1=x3-d; x2=x3+d
  ! Calculate Mueller parameters and guard against divide by zero
  if (x2-x1==0) x2=x2*1.0000001
100 if (x2-x1==0) x2=x2+0.0000001
  xl1=(x3-x2)/(x2-x1)
  d1=(x3-x1)/(x2-x1)
  if (k>1) goto 200
  ! Get values of function
  e1=gittins(x1); e2=gittins(x2)
200 e3=gittins(x3)
  a1=xl1*xl1*e1-d1*d1*e2+(xl1+d1)*e3
  c1=xl1*(xl1*e1-d1*e2+e3)
  b=a1*a1-4.d0*d1*c1*e3
  ! Test for complex root, meaning the parabola is inverted
  if (b<0) b=0.d0
  ! Choose closest root
  if (a1<0) a1=a1-dsqrt(b)
  if (a1>0) a1=a1+dsqrt(b)
  ! Guard against divide by zero
  if (a1==0) a1=1.d-12
  xl=-2.d0*d1*e3/a1
  ! Calculate next estimate
  x=x3+xl*(x3-x2)
  ! Test for convergence
  if (dabs(x-x3)<e) return
  ! Test for number of iterations
  !if (k>=n) return
  ! Otherwise, make another pass
  k=k+1
  ! Some saving
  x1=x2; x2=x3; x3=x; e1=e2; e2=e3


  goto 100
end subroutine !of subroutine Mueller() 

subroutine d_mrgref (XVALT, IRNGT,NX)
          use mod_types
!   Ranks array XVALT into index array IRNGT, using merge-sort
! __________________________________________________________
!   This version is not optimized for performance, and is thus
!   not as difficult to read as some other ones.
!   Michel Olagnon - April 2000
! __________________________________________________________
! __________________________________________________________
      !real(dp), Dimension (:), Intent (In) :: XVALT
      !Integer, Dimension (:), Intent (Out) :: IRNGT
! __________________________________________________________
!
     
      real(dp),dimension(NX), intent(in) :: XVALT
      integer,dimension(NX), intent(out) :: IRNGT
      Integer, Dimension (:), Allocatable :: JWRKT
      Integer :: LMTNA, LMTNC
      Integer :: NVAL, IIND, IWRKD, IWRK, IWRKF, JINDA, IINDA, IINDB

      
      NVAL = Min (SIZE(XVALT), SIZE(IRNGT))
      If (NVAL <= 0) Then
         Return
      End If
!
!  Fill-in the index array, creating ordered couples
!
      Do IIND = 2, NVAL, 2

         If (XVALT(IIND-1) < XVALT(IIND)) Then
            IRNGT (IIND-1) = IIND - 1
            IRNGT (IIND) = IIND
         Else
            IRNGT (IIND-1) = IIND
            IRNGT (IIND) = IIND - 1
         End If
      End Do
      If (Modulo (NVAL, 2) /= 0) Then
         IRNGT (NVAL) = NVAL
      End If
!
!  We will now have ordered subsets A - B - A - B - ...
!  and merge A and B couples into     C   -   C   - ...
!
      Allocate (JWRKT(1:NVAL))
      LMTNC = 2
      LMTNA = 2
!
!  Iteration. Each time, the length of the ordered subsets
!  is doubled.
!
      Do
         If (LMTNA >= NVAL) Exit
         IWRKF = 0
         LMTNC = 2 * LMTNC
         IWRK = 0
!
!   Loop on merges of A and B into C
!
         Do
            IINDA = IWRKF
            IWRKD = IWRKF + 1
            IWRKF = IINDA + LMTNC
            JINDA = IINDA + LMTNA
            If (IWRKF >= NVAL) Then
               If (JINDA >= NVAL) Exit
               IWRKF = NVAL
            End If
            IINDB = JINDA
!
!   Shortcut for the case when the max of A is smaller
!   than the min of B (no need to do anything)
!
            If (XVALT(IRNGT(JINDA)) <= XVALT(IRNGT(JINDA+1))) Then
               IWRK = IWRKF
               Cycle
            End If
!
!  One steps in the C subset, that we create in the final rank array
!
            Do
               If (IWRK >= IWRKF) Then
!
!  Make a copy of the rank array for next iteration
!
                  IRNGT (IWRKD:IWRKF) = JWRKT (IWRKD:IWRKF)
                  Exit
               End If
!
               IWRK = IWRK + 1
!
!  We still have unprocessed values in both A and B
!
               If (IINDA < JINDA) Then
                  If (IINDB < IWRKF) Then
                     If (XVALT(IRNGT(IINDA+1)) > XVALT(IRNGT(IINDB+1))) &
                    & Then
                        IINDB = IINDB + 1
                        JWRKT (IWRK) = IRNGT (IINDB)
                     Else
                        IINDA = IINDA + 1
                        JWRKT (IWRK) = IRNGT (IINDA)
                     End If
                  Else
!
!  Only A still with unprocessed values
!
                     IINDA = IINDA + 1
                     JWRKT (IWRK) = IRNGT (IINDA)
                  End If
               Else
!
!  Only B still with unprocessed values
!
                  IRNGT (IWRKD:IINDB) = JWRKT (IWRKD:IINDB)
                  IWRK = IWRKF
                  Exit
               End If
!
            End Do
         End Do
!
!  The Cs become As and Bs
!
         LMTNA = 2 * LMTNA
      End Do
!
!  Clean up
!
      Deallocate (JWRKT)
      Return

      End Subroutine D_mrgref


function r8_normal_01 (u1,u2 )
!c*********************************************************************
!c
!cc R8_NORMAL_01 returns a unit pseudonormal R8.
!c
!c  Licensing:
!c
!c    This code is distributed under the GNU LGPL license.
!c
!c  Modified:
!c
!c    06 August 2013
!c
!c  Author:
!c
!c    John Burkardt
!c
!c  Parameters:
!c
      implicit none

      double precision pi
      parameter ( pi = 3.141592653589793D+00 )
      double precision u1 
      double precision u2
      double precision r8_normal_01
      double precision x

      x = sqrt ( -2.0D+00 * log ( u1 ) ) * cos ( 2.0D+00 * pi * u2 )

      r8_normal_01 = x

      return
      end function

end module utils
