rm(list=ls())
library(MASS)
library(plyr)

# This program takes data generated by the code in
# hkp_data_results.R and generates files to be used by the fortran
# code.

# The set of moments that simulation estimation uses includes:
# portfolio shares by occupation (Humanities and Quantitative),
# Fraction of Switchers by occupation, the standard deviation of log
# earnings in the first period, the Standard deviations of shares by
# skill (aggregate, not by occupation), the fraction of stay-switch
# events, correlations among different credits, and the overall number
# of switchers.

pathtofortran <- "../HKP_Fortran_Code/"
pathtostruct = "../HKP_Files_for_Struc_Estimation/"

# Load the portfolio shares 

port_shares <-
    read.table(file=paste0(pathtostruct,"Portfolio_moments_struct.csv"),
               sep=",",header=T)

hkp_data_for_table <- mat.or.vec(1,3)
# Load sample size by occupation
nobsbyocc <- read.table(file=paste0(pathtostruct,"Sample_Size_by_Occ.csv"),
                        sep=",",header=T)
nobs<-nobsbyocc[1:12,]
nobs_total<-nobsbyocc[13,]
hkp_data_for_table <-rbind(hkp_data_for_table,
                           cbind(port_shares$w_hum.mean,sqrt(port_shares$w_hum.sd^2/nobs$x),round_any(nobs[,2],10)))


hkp_data_for_table<-rbind(hkp_data_for_table,cbind(port_shares$w_math.mean,sqrt(port_shares$w_math.sd^2/nobs$x),round_any(nobs[,2],10)))

# Load jumps by occ
occjumps <- read.table(file=paste0(pathtostruct,"Percentage_Switches_by_Occ.csv"),sep=",", header = T)
hkp_data_for_table <-rbind(hkp_data_for_table,cbind(occjumps$iswitch1.mean,sqrt(occjumps$iswitch1.var/nobs$x),round_any(nobs[,2],10)))

# Load standard deviations of portfolio weights for each type of
# skill.
std_shares_skills <- read.table(file=paste0(pathtostruct,"Stdevs_Shares_by_Skill.csv"),
                                sep=",", header=T)

hkp_data_for_table <-rbind(hkp_data_for_table,cbind(std_shares_skills$V2,std_shares_skills$V2/sqrt(2*(nobs_total$x-1)),round_any(nobs_total$x,10)))


# Load Standard Deviation of (Log) Earnings for first period
sd_earn_init <- read.table(file=paste0(pathtostruct,"Stdev_initial_log_wage.csv"),sep=",", header = T) 

hkp_data_for_table <-rbind(hkp_data_for_table,cbind(sd_earn_init$x,sd_earn_init$x/sqrt(2*(nobs_total$x-1)),round_any(nobs_total$x,10)))


# Load fraction of stay-switch events 
stay_switch_fraction <- read.table(file=paste0(pathtostruct,"Stay_Switch_Fraction.csv"),
                                sep=",", header=T)


hkp_data_for_table <-rbind(hkp_data_for_table,cbind(stay_switch_fraction$x[1],sqrt(stay_switch_fraction$x[2]^2/nobs_total$x),round_any(nobs_total$x,10)))


# Load correlations between amount of credits
correl_credits <- read.table(file=paste0(pathtostruct,"Correlations_of_Amount_of_Credits.csv"),
                                sep=",", header=T)


hkp_data_for_table <-rbind(hkp_data_for_table,cbind(correl_credits$x,sqrt(((1-correl_credits$x^2)^2)/(nobs_total$x-1)),round_any(nobs_total$x,10)))

#intensity_moments <- read.table(file=paste0(pathtostruct,"intensity_moments.csv"),
#                                sep=",", header=T)

overall_switching_rate <-
    read.table(file=paste0(pathtostruct,"overall_switching_rate.csv"),
                               sep=",", header=T)
hkp_data_for_table <-rbind(hkp_data_for_table,cbind(overall_switching_rate$V1,sqrt(overall_switching_rate$V2^2/nobs_total$x),round_any(nobs_total$x,10)))

#hkp_data_for_table <-rbind(hkp_data_for_table,cbind(intensity_moments$V1,sqrt(intensity_moments$V2^2/nobs_total$x),round_any(nobs_total$x,10)))
hkp_data_for_table <- hkp_data_for_table[-1,]


write.matrix(hkp_data_for_table[,1],file = paste0(pathtofortran,"emptargets.txt"))
write.matrix(1/hkp_data_for_table[,2]^2,file = paste0(pathtofortran,"dataweights.txt"))
write.matrix(hkp_data_for_table[,1],file = paste0(pathtostruct,"emptargets.txt"))
write.matrix(1/hkp_data_for_table[,2]^2,file = paste0(pathtostruct,"dataweights.txt"))
write.matrix(hkp_data_for_table,file = paste0(pathtostruct,"struct_data_for_latex.txt"))

