# clear workspace
rm(list=ls())

# Load a few necessary libraries
library(doBy)
library(gdata)
library(Hmisc)
library(moments)
library(plyr)
library(dummies)
library(ineq)

# Set some directories for I/O
pathtodata = "../HKP_Data/"
pathtodir = "../HKP_Data_Regression_Results/" 
pathtostruct = "../HKP_Files_for_Struc_Estimation/"

# vectors that determine different cases/definitions 
art_ind_vec <- c(1,0) # with (without) arts 
                      # as a separate human capital

weight_ind_vec <- c(1,0) # credits weighted or not when computing
                         # human capital portfolios

major_ind_vec <- c(1,0) # Control (or not) for major in regressions

art_ind_labels <- c("with_arts","without_arts")
weight_ind_labels <- c("_weighted_GPA","_unweighted_GPA")
major_ind_labels <- c("_major","_nomajor")

#Go through all the cases
for (i in c(1,2)) {
    for (j in c(1,2)) {
        for (k in c(1,2)) {

        filename <- paste0("_table_",art_ind_labels[i],weight_ind_labels[j],
                           major_ind_labels[k],".txt")
                    
        # a few indicators that determine different cases. 
        with_arts_indicator <- art_ind_vec[i] # 1: four human capital types (arts is a
                                              # separate category. 0: four types (arts is
                                              # within humanities.
        
        with_weighted_credits_indicator <- weight_ind_vec[j] # 1: compute portfolios 
                                                             # and diversification
                                                             # with weighted credits , 
                                                             # 0: unweighted
        
        with_major_indicator <- major_ind_vec[k] # 1: conditions for major 
                                                 # in the regressions (fewer observations)
                                                 # 0: does not control for major
        
        # load PETS 
        load(paste0(pathtodata,"PETS.Rdata"))
        # include obs that have information about graduation year
        data_pets<-data_pets[!is.nan(data_pets$DEGYEAR),]
        
        data_pets<-data_pets[data_pets$HSBSTAT==1 & data_pets$NHDEG>1,]
        data_pets<-data_pets[data_pets$DEGYEAR>=0,]
        
        # Some repeat individuals (because they have more than one
        # degree (take the earlier one as reference. See online
        # appendix for details. 
        find_min_yr <- summaryBy(DEGYEAR~ID, data = data_pets,FUN=min)
        new_pets <- merge(find_min_yr,data_pets,by="ID")
        
        # relabel Degyear as the earlier year
        new_pets$DEGYEAR <- new_pets$DEGYEAR.min
        data_pets <- new_pets
        print('PETS Data:')
        print(dim(data_pets))
        data_pets <- data_pets[!duplicated(data_pets$ID),]
        
        # load HSB
        load(paste0(pathtodata,"HSB.Rdata"))
        print('HSB data:')
        print(dim(data_HSB))
        
        # Merge both datasets 
        alldata <- merge(data_HSB,data_pets,by.x="ID",by.y="ID",incomparables=NA)
        print('Original Size Merged')
        print(dim(alldata))
        
        # Call code to clean data and relabel a few variables. It also
        # defines a string vector called "myvars", which enumerates
        # the variables to keep.
        source('clean_data.R')
        
        # Define additional variables for analysis and some further
        # cleaning.
        source('variable_definitions.R')        
        
        #---------------------------------------------------------------------
        # do regressions without controlling for major
        #---------------------------------------------------------------------
        
        if (with_major_indicator==0) {
        
            source('regressions_no_major.R')
            
                    # with the larger sample (no major) compute moments for 
                    # structural estimation
        
                    if (with_major_indicator==0 & with_arts_indicator==0 &
                    with_weighted_credits_indicator == 0) {
                    
                        source('moments_for_estimation.R')
        
                    }
        
        } else { 
            
            # control for major in what follows
            source('regressions_with_major.R')
           
        }


          }
    }
}



