rm(list=ls())
library(scales)
library(ggplot2)

# set directory labels
pathtodata <- "../HKP_Data_Regression_Results/"
pathtostruct <-  "../HKP_Files_for_Struc_Estimation/"
pathtodir <- "../HKP_Latex_Files/" 
pathtofortran <- "../HKP_Fortran_Code/"


# Begin output to Latex tables

#_________________________________________________________________
# Table with portfolios by occupation
#_________________________________________________________________

filename <- paste0(pathtodata,"Numbers_for_Table_1.csv")
unlink(paste0(pathtodir,"Table_Portfolios_By_Occ.tex"),recursive=F,force=F)
tabfile <-paste0(pathtodir,"Table_Portfolios_By_Occ.tex")
zmat <- read.table(filename,header=T, sep=",")
# There are a total of 14 occs.
occlabels <- c("Clerical", "Manager", "Skilled Operative",
               "Professional -
               Arts","Professional - Medical","Professional -
               Engineering", "Professional -
               Other", "Sales", "School Teacher", "Service","Owner",
               "Technician - Computer-Related", "Technician - Non
               Computer-Related","Laborer/Homemaker")
# Start printing out table
write(sprintf("{"),file=tabfile,append=T)
write(sprintf("\\def\\sep{0.5em}"),file=tabfile,append=T)
write(sprintf("\\def\\fns{\\footnotesize}"),file=tabfile,append=T)

write(sprintf("\\begin{table}[!htbp]\\centering"),file=tabfile,append=T)
write(sprintf("\\begin{threeparttable}"),file=tabfile,append=T)

write(sprintf("\\caption{Empirical Human Capital Portfolios By
              Occupation (1991)}"),file=tabfile,append=T)
write(sprintf("\\begin{tabular}{lccc}"),file=tabfile,append=T)
write(sprintf("& & &\\tabularnewline"),file=tabfile,append=T)
write(sprintf("\\toprule"),file=tabfile,append=T)
write(sprintf("Occupation & {Share Hum.} & {Share Quant.}&{Share Soc.
             Sci.} \\tabularnewline \\toprule"),file=tabfile,append=T)
for (i in seq(1,14)){
write(sprintf("%s  & %.3f & %.3f &%.3f
             \\tabularnewline",occlabels[i],zmat$w_hum.mean[i],zmat$w_math.mean[i],zmat$w_socsci.mean[i]),file=tabfile,append=T)
write(sprintf(" &  \\fns{(\\emph{%.3f}) } & \\fns{(\\emph{%.3f}) } &
              \\fns{(\\emph{%.3f}) }
              \\tabularnewline",zmat$w_hum.sd[i],zmat$w_math.sd[i],zmat$w_socsci.sd[i]),file=tabfile,append=T)
#[\sep]
}

write(sprintf("\\midrule"),file=tabfile,append=T)

all_occ_portfolio<-read.table(paste0(pathtodata,"Portfolios_All_Occs.csv"), header=T, sep=",")
write(sprintf("All Occupations & %.3f & %.3f & %.3f \\tabularnewline",
              all_occ_portfolio$V1[1],all_occ_portfolio$V1[2],all_occ_portfolio$V1[3]),file=tabfile,append=T)
write(sprintf(" & \\fns{(\\emph{%.3f}) } &
              \\fns{(\\emph{%.3f})}&\\fns{(\\emph{%.3f)} }
              \\tabularnewline",
              all_occ_portfolio$V2[1],all_occ_portfolio$V1[2],all_occ_portfolio$V1[3]),file=tabfile,append=T)
#

write(sprintf("\\bottomrule"),file=tabfile,append=T)
write(sprintf("\\label{tab:portfolios}"),file=tabfile,append=T)
write(sprintf("\\end{tabular}"),file=tabfile,append=T)
write(sprintf("\\begin{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\scriptsize"),file=tabfile,append=T)
write(sprintf("\\item \\emph{Notes}: Each cell displays the average, across all individuals
working in an occupation, of the portfolio weight of a given human capital type. The
standard
deviation of the distribution of the portfolio weight across
individuals is in
parentheses."),file=tabfile,append=T)
write(sprintf("\\end{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\end{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\end{table}"),file=tabfile,append=T)
write(sprintf("}"),file=tabfile,append=T)

#_________________________________________________________________
# Summary/Correlation Table 
#_________________________________________________________________

filename_a <-  paste0(pathtodata,"Summary_Selected_Table2.csv")
filename_b <- paste0(pathtodata,"Correlations_CorrMat_Table2.csv")

unlink(paste0(pathtodir,"Summary_Correlations_Data.tex"),recursive=F,force=F)
mat_for_summary <- read.table(file = filename_a,header=T,sep=",")[,-1]
corrmat <- read.table(file=filename_b,header=T,sep=",")[,-1]
signif<-
    read.table(file=paste0(pathtodata,"Significance_CorrMat_Table2.csv"),header=T,sep=",")[,-1]
tabfile <-paste0(pathtodir,"Summary_Correlations_Data.tex")
varlabels <-c("{$\\delta$}","{$log(Y_{91})$}","{$\\Delta
              Y$}","{$CRED$}","{$STAY$}") 

# matrix to summarize significance levels
d <- matrix(as.character(mat.or.vec(5,5)),nrow=5,ncol=5)
for (i in seq(1,5)){
 for (j in seq(i,5)){
  if (i==j)
            {d[i,j] = ""} 
            else 
            {
               if (signif[i,j]<0.01) { 
                d[i,j] ="^{**}"}
               else if (signif[i,j]>0.01&signif[i,j]<0.1){
                d[i,j] ="^{*}"}
               else {
                   d[i,j] = ""}
            }
            }
            }




write(sprintf("{"),file = tabfile, append = T)
write(sprintf("\\begin{table}[h]"),file = tabfile, append = T)
write(sprintf("\\centering"),file = tabfile, append = T)
write(sprintf("\\begin{threeparttable}"),file = tabfile, append = T)
write(sprintf("\\caption{Summary Statistics - Selected Variables}"),file = tabfile, append = T)
write(sprintf("\\smallskip"),file = tabfile, append = T)
write(sprintf("\\begin{tabular}{cccccc}"),file = tabfile, append = T)
write(sprintf("\\toprule"),file = tabfile, append = T)
write(sprintf(" &  {Mean} &  {Median} &  {Std. Dev.}&  {Min.} &
              {Max.}    \\tabularnewline"),file = tabfile, append = T)
             
              write(sprintf(" \\midrule"),file = tabfile, append = T)
for (i in seq(1,5)){
sumvec <- mat_for_summary[i,]
if (i == 4) {   
write(sprintf("  {%s}  & %.0f &  %.0f & %.0f & %.0f & %.0f
              \\tabularnewline",varlabels[i],round(sumvec[1],0),round(sumvec[2],0),round(sumvec[3],0),round(sumvec[4],0),round(sumvec[5],0)),file = tabfile, append = T)
} else {
write(sprintf("  {%s}  & %.3f &  %.3f  &  %.3f  & %.3f &  %.3f
              \\tabularnewline",varlabels[i],sumvec[1],sumvec[2],sumvec[3],sumvec[4],sumvec[5]),file = tabfile, append = T)
}
}
write(sprintf("\\bottomrule"),file = tabfile, append = T)
write(sprintf("\\end{tabular}"),file = tabfile, append = T)
write(sprintf("\\begin{tablenotes}"),file = tabfile, append = T)
write(sprintf("\\scriptsize"),file = tabfile, append = T)
write(sprintf("\\smallskip"),file = tabfile, append = T)
write(sprintf("\\item \\emph{Notes}: The table reports summary
              statistics for a few variables of interest in the
              baseline sample of the HSB Study. $\\delta$ denotes our
              measure of distance described in the text. $log(Y_{91})$
              is the log of earnings (in 2010 dollars) at the end of our sample (1991),
              $\\Delta Y$ is growth rate of earnings during a worker's
              early labor market history, $CRED$ is the number of
              credits taken, and $STAY$ is defined as 1 if a worker
              does not switch occupations and 0 otherwise."),file = tabfile, append = T)
write(sprintf("\\end{tablenotes} \\bigskip"),file = tabfile, append = T)
write(sprintf("\\centering"),file = tabfile, append = T)
write(sprintf("Correlation Matrix - Selected Variables
              \\tabularnewline"),file = tabfile, append = T)
write(sprintf("\\bigskip"),file = tabfile, append = T)
write(sprintf("\\centering"),file = tabfile, append = T)
write(sprintf("\\begin{tabular}{cccccc}"),file = tabfile, append = T)
write(sprintf("\\toprule"),file = tabfile, append = T)
write(sprintf("& %s & %s & %s & %s & %s \\tabularnewline", varlabels[1] , varlabels[2] , {varlabels[3]} ,  {varlabels[4]}, {varlabels[5]}),file=tabfile,append=T)
write(sprintf("\\midrule"),file=tabfile,append=T)

write(sprintf("%s &  %s & %s& %s   &  %s   &  %s \\tabularnewline",
              varlabels[1],
              paste0("$",sprintf("%.3f",corrmat[1,1]),d[1,1],"$"),
              paste0("$",round(corrmat[1,2],3),d[1,2],"$"),
              paste0("$",round(corrmat[1,3],3),d[1,3],"$"),
              paste0("$",round(corrmat[1,4],3),d[1,4],"$"),
              paste0("$",round(corrmat[1,5],3),d[1,5],"$")),file=tabfile,append=T)

write(sprintf("%s &  & %s& %s   &  %s   &  %s \\tabularnewline",
              varlabels[2],
              paste0("$",sprintf("%.3f",corrmat[2,2]),d[2,2],"$"),
              paste0("$",round(corrmat[2,3],3),d[2,3],"$"),
              paste0("$",round(corrmat[2,4],3),d[2,4],"$"),
              paste0("$",round(corrmat[2,5],3),d[2,5],"$")),file=tabfile,append=T)

write(sprintf("%s &   & & %s   &  %s   &  %s \\tabularnewline",
              varlabels[3],
              paste0("$",sprintf("%.3f",corrmat[3,3]),d[3,3],"$"),
              paste0("$",round(corrmat[3,4],3),d[3,4],"$"),
              paste0("$",round(corrmat[3,5],3),d[3,5],"$")),file=tabfile,append=T)

write(sprintf("%s &  & &   &  %s   &  %s \\tabularnewline",
              varlabels[4],
              paste0("$",sprintf("%.3f",corrmat[4,4]),d[4,4],"$"),
              paste0("$",round(corrmat[4,5],3),d[4,5],"$")),file=tabfile,append=T)

write(sprintf("%s &  & &   &    &  %s \\tabularnewline",
              varlabels[5],
              paste0("$",sprintf("%.3f",corrmat[5,5]),d[5,5],"$")),
      file=tabfile,append=T)


write(sprintf("\\bottomrule"),file = tabfile, append = T)
write(sprintf("\\end{tabular}"),file = tabfile, append = T)
write(sprintf("\\begin{tablenotes}"),file = tabfile, append = T)
write(sprintf("\\scriptsize"),file = tabfile, append = T)
write(sprintf("\\smallskip"),file = tabfile, append = T)
write(sprintf("\\item \\emph{Notes}: The table reports unconditional
              correlations among a few variables of interest in the
              baseline sample of the HSB Study. $\\delta$ denotes our
              measure of distance described in the text. $log(Y_{91})$
              is the log of earnings (in 2010 dollars) at the end of our sample (1991),
              $\\Delta Y$ is growth rate of earnings during a worker's
              early labor market history, $CRED$ is the number of
              credits taken, and $STAY$ is defined as 1 if a worker
              does not switch occupations and 0 otherwise. {*}: Correlation is significant at least at the 0.05 level.
{**}: Correlation is significant at least at the 0.01 level."),file = tabfile, append = T)
write(sprintf("\\end{tablenotes} \\bigskip"),file = tabfile, append = T)
write(sprintf("\\label{tab:summary}"),file = tabfile, append = T)
write(sprintf("\\end{threeparttable}"),file = tabfile, append = T)
write(sprintf("\\end{table}"),file = tabfile, append = T)
write(sprintf("}"),file = tabfile, append = T)

#_________________________________________________________________
# Data OLS Regression Table
#_________________________________________________________________

filename <- paste0("_table_without_arts_weighted_GPA_major.txt")

zmat1 <- read.table(file=paste0(pathtodata,"reg1_",filename),header=T,sep=",") 
zmat2 <- read.table(file=paste0(pathtodata,"reg2_",filename),header=T,sep=",") 
zmat3 <- read.table(file=paste0(pathtodata,"reg3_",filename),header=T,sep=",") 
zmat4 <- read.table(file=paste0(pathtodata,"reg4_",filename),header=T,sep=",")

# matrix to summarize significance levels (to print significance stars
# in tables)

d1 <- matrix(as.character(mat.or.vec(dim(zmat4)[1],4)),nrow=dim(zmat4)[1],ncol=4)
pvalmat <- matrix(mat.or.vec(dim(zmat4)[1],4),nrow=dim(zmat4)[1],ncol=4)
pvalmat[1:dim(zmat1)[1],1] <- zmat1[,5]
pvalmat[1:dim(zmat2)[1],2] <- zmat2[,5]
pvalmat[1:dim(zmat3)[1],3] <- zmat3[,5]
pvalmat[1:dim(zmat4)[1],4] <- zmat4[,5]
#pvalmat <- as.numeric(pvalmat)
kdim = dim(zmat1)[1]
for (j in seq(1,4)){

       for (i in seq(1,kdim)){
                      if (pvalmat[i,j]<0.01) { 
                       d1[i,j] ="^{\\fns{***}}"}
                      else if (pvalmat[i,j]>0.01&pvalmat[i,j]<0.05){
                       d1[i,j] ="^{\\fns{**}}"}
                      else if (pvalmat[i,j]>0.05&pvalmat[i,j]<0.1){
                       d1[i,j] ="^{\\fns{*}}"}
                      else {
                          d1[i,j] = "\\hspace{0.2in}"}
                   
                   }
              kdim = kdim + 1
            }
             

unlink(paste0(pathtodir,"ols_data_reg_table.tex"),recursive=F,force=F)
tabfile =paste0(pathtodir,"ols_data_reg_table.tex") 
write(sprintf("{"),file=tabfile,append=T)
write(sprintf("\\def\\sep{0.5em}"),file=tabfile,append=T)
write(sprintf("\\def\\fns{\\footnotesize}"),file=tabfile,append=T)
write(sprintf("\\begin{table}[!htbp]"),file=tabfile,append=T)
write(sprintf("\\centering"),file=tabfile,append=T)
write(sprintf("\\begin{threeparttable}"),file=tabfile,append=T)
write(sprintf(paste0("\\caption{OLS Regression Results - Dependent Variable is
              $log(Y_{91})$}")),file=tabfile,append=T)
write(sprintf("\\smallskip"),file=tabfile,append=T)

write(sprintf("\\begin{tabular}{lllll}"),file=tabfile,append=T)
write(sprintf("\\toprule"),file=tabfile,append=T)
write(sprintf("\\multicolumn{5}{c}{ {Coeff.} } \\tabularnewline"),file=tabfile,append=T)
write(sprintf("\\multicolumn{5}{c}{ {\\fns(\\emph{t-stat.})}} \\tabularnewline"),file=tabfile,append=T)
write(sprintf(" &  {(1)} &  {(2)}& {(3)} &  {(4)}  \\tabularnewline"),file=tabfile,append=T)
write(sprintf("\\midrule"),file=tabfile,append=T)

write(sprintf(" {$log(Y_{91-T})$}  &  %s      &  %s &  %s &
               %s\\tabularnewline", paste0('$',sprintf("%.3f",zmat1$V1[2]),d1[2,1],'$'), paste0('$',sprintf("%.3f",zmat2$V1[2]),d1[2,2],'$'), paste0('$',sprintf("%.3f",zmat3$V1[2]),d1[2,3],'$'), paste0('$',sprintf("%.3f",zmat4$V1[2]),d1[2,4],'$')),file=tabfile,append=T)

write(sprintf(" & \\fns{\\emph{(%.2f)}}   & \\fns{\\emph{(%.2f)}} &\\fns{\\emph{(%.2f)}} &\\fns{\\emph{(%.2f)}}\\tabularnewline[\\sep]",zmat1$V2[2],zmat2$V2[2],zmat3$V2[2],zmat4$V2[2]),file=tabfile,append=T)


write(sprintf(" {$log(CRED)$}  &   %s      &  %s &  %s &
               %s\\tabularnewline", paste0('$',sprintf("%.3f",zmat1$V1[3]),d1[3,1],'$'), paste0('$',sprintf("%.3f",zmat2$V1[3]),d1[3,2],'$'), paste0('$',sprintf("%.3f",zmat3$V1[3]),d1[3,3],'$'), paste0('$',sprintf("%.3f",zmat4$V1[3]),d1[3,4],'$')),file=tabfile,append=T)

write(sprintf(" & \\fns{\\emph{(%.2f)}}   & \\fns{\\emph{(%.2f)}}
&\\fns{\\emph{(%.2f )}}  &\\fns{\\emph{(%.2f)}}\\tabularnewline[\\sep]", zmat1$V2[3],zmat2$V2[3],zmat3$V2[3],zmat4$V2[3]),file=tabfile,append=T)

write(sprintf("{$SEX$}		       &   %s      &  %s &  %s &
               %s\\tabularnewline", paste0('$',sprintf("%.3f",zmat1$V1[4]),d1[4,1],'$'), paste0('$',sprintf("%.3f",zmat2$V1[4]),d1[4,2],'$'), paste0('$',sprintf("%.3f",zmat3$V1[4]),d1[4,3],'$'), paste0('$',sprintf("%.3f",zmat4$V1[4]),d1[4,4],'$')),file=tabfile,append=T)

write(sprintf("  & \\fns{\\emph{(%.2f)}}   & \\fns{\\emph{(%.2f)}}
&\\fns{\\emph{(%.2f )}}  &\\fns{\\emph{(%.2f)}}\\tabularnewline[\\sep]", zmat1$V2[4],zmat2$V2[4],zmat3$V2[4],zmat4$V2[4]),file=tabfile,append=T)
 
write(sprintf("{$\\delta$}    &   %s      &  %s &  %s &
               %s\\tabularnewline", paste0('$',sprintf("%.3f",zmat1$V1[5]),d1[5,1],'$'), paste0('$',sprintf("%.3f",zmat2$V1[5]),d1[5,2],'$'), paste0('$',sprintf("%.3f",zmat3$V1[5]),d1[5,3],'$'), paste0('$',sprintf("%.3f",zmat4$V1[5]),d1[5,4],'$')),file=tabfile,append=T)


 write(sprintf(" & \\fns{\\emph{(%.2f)}}   & \\fns{\\emph{(%.2f)}}
&\\fns{\\emph{(%.2f )}}  &\\fns{\\emph{(%.2f)}}\\tabularnewline[\\sep]",
zmat1$V2[5],zmat2$V2[5],zmat3$V2[5],zmat4$V2[5]),file=tabfile,append=T)
 

write(sprintf("{$STAY$}              &         &  %s &  %s &
               %s\\tabularnewline",paste0('$',sprintf("%.3f",zmat2$V1[6]),d1[6,2],'$'), paste0('$',sprintf("%.3f",zmat3$V1[6]),d1[6,3],'$'), paste0('$',sprintf("%.3f",zmat4$V1[6]),d1[6,4],'$')),file=tabfile,append=T)



write(sprintf("	& & \\fns{\\emph{(%.2f)}} & \\fns{\\emph{(%.2f)}} &
 \\fns{\\emph{(%.2f)}} \\tabularnewline[\\sep]",zmat2$V2[6],zmat3$V2[6],zmat4$V2[6]),file=tabfile,append=T)


write(sprintf("{$CAREER$}	      &        &   &  %s &
               %s\\tabularnewline",paste0('$',sprintf("%.3f",zmat3$V1[7]),d1[7,3],'$'),paste0('$',sprintf("%.3f",zmat4$V1[7]),d1[7,4],'$')),file=tabfile,append=T)

write(sprintf("&        &   &  \\fns{\\emph{(%.2f)}}  & \\fns{\\emph{(%.2f)}} \\tabularnewline[\\sep]",zmat3$V2[7],zmat4$V2[7]),file=tabfile,append=T)


write(sprintf(" {$\\delta\\times STAY$}  &        &  &  &
               %s\\tabularnewline",paste0('$',sprintf("%.3f",zmat4$V1[8]),d1[8,4],'$')),file=tabfile,append=T)

			write(sprintf("			  &        &       &          & \\fns{\\emph{(%.2f)}} \\tabularnewline[\\sep]",zmat4$V2[8]),file=tabfile,append=T)

write(sprintf("{Intercept}  &   %s      &  %s &  %s & %s\\tabularnewline",paste0('$',sprintf("%.3f",zmat1$V1[1]),d1[1,1],'$'), paste0('$',sprintf("%.3f",zmat2$V1[1]),d1[1,2],'$'),paste0('$',sprintf("%.3f",zmat3$V1[1]),d1[1,3],'$'), paste0('$',sprintf("%.3f",zmat4$V1[1]),d1[1,4],'$')),file=tabfile,append=T)


write(sprintf(" & \\fns{\\emph{(%.2f)}}   & \\fns{\\emph{(%.2f)}}
&\\fns{\\emph{(%.2f)}}  &\\fns{\\emph{(%.2f)}}\\tabularnewline",
zmat1$V2[1],zmat2$V2[1],zmat3$V2[1],zmat4$V2[1]),file=tabfile,append=T)
write(sprintf("\\midrule"),file=tabfile,append=T)
write(sprintf("{$N$}  & %s & %s  & %s &
              %s\\tabularnewline",comma(zmat1$V3[1]),comma(zmat2$V3[1]),comma(zmat3$V3[1]),comma(zmat4$V3[1])),file=tabfile,append=T)
write(sprintf("{$R^2$}  & %.3f & %.3f& %.3f &
              %.3f\\tabularnewline",zmat1$V4[1],zmat2$V4[1],zmat3$V4[1],zmat4$V4[1]),file=tabfile,append=T)
write(sprintf("\\bottomrule"),file=tabfile,append=T)
write(sprintf("\\end{tabular}"),file=tabfile,append=T)
write(sprintf("\\label{tab:regsimple}"),file=tabfile,append=T)
write(sprintf("\\begin{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\scriptsize"),file=tabfile,append=T)
write(sprintf("\\smallskip"),file=tabfile,append=T)
write(sprintf("\\item \\emph{Notes}: The table reports coefficient
estimates (and estimated $t$-statistics in parentheses) from
regressing final earnings ($log(Y_{91}))$ on the variables displayed
on the first column. $log(Y_{91-T})$ denotes initial earnings
(post-graduation), $SEX$ is defined as 1 if the worker is a female and
0 otherwise, $log(CRED)$ is the log of credits, $\\delta$ denotes our
measure of distance described in the text, $STAY$ is defined as 1 if a
worker does not switch occupations and 0 otherwise, and $CAREER$ is
defined as 1 if a worker begins her labor market experience in a
non-managerial occupation and ends in a managerial one.  Additional
regressors (coefficients not shown) are GPA and dummies for
occupations, type of degree, and major.  Coefficient significantly
different from zero at least at the 0.1 level ({*}), at least 
at the 0.05 level ({**}), and 
at least at the 0.01 level ({***})."),file=tabfile,append=T)
write(sprintf("\\end{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\end{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\end{table}"),file=tabfile,append=T)
write(sprintf("}"),file=tabfile,append=T)

#_________________________________________________________________
# Data Probit Regression Table
#_________________________________________________________________

filename <- paste0("_table_without_arts_weighted_GPA_major.txt")

zmat1 <- read.table(file=paste0(pathtodata,"probit1_",filename),header=T,sep=",") 
zmat2 <- read.table(file=paste0(pathtodata,"probit2_",filename),header=T,sep=",") 
zmat3 <- read.table(file=paste0(pathtodata,"probit3_",filename),header=T,sep=",") 
zmat4 <- read.table(file=paste0(pathtodata,"probit4_",filename),header=T,sep=",")

unlink(paste0(pathtodir,"probit_data_reg_table.tex"),recursive=F,force=F)
tabfile =paste0(pathtodir,"probit_data_reg_table.tex") 

# matrix to summarize significance levels (to print significance stars
# in tables)

d1 <- matrix(as.character(mat.or.vec(dim(zmat4)[1],4)),nrow=dim(zmat4)[1],ncol=4)
pvalmat <- matrix(mat.or.vec(dim(zmat4)[1],4),nrow=dim(zmat4)[1],ncol=4)

pvalmat[1:dim(zmat1)[1],1] <- zmat1[,4]
pvalmat[1:dim(zmat2)[1],2] <- zmat2[,4]
pvalmat[1:dim(zmat3)[1],3] <- zmat3[,4]
pvalmat[1:dim(zmat4)[1],4] <- zmat4[,4]
#pvalmat <- as.numeric(pvalmat)
kdim = dim(zmat1)[1]
for (j in seq(1,4)){

       for (i in seq(1,kdim)){
                      if (pvalmat[i,j]<0.01) { 
                       d1[i,j] ="^{\\fns{***}}"}
                      else if (pvalmat[i,j]>0.01&pvalmat[i,j]<0.05){
                       d1[i,j] ="^{\\fns{**}}"}
                      else if (pvalmat[i,j]>0.05&pvalmat[i,j]<0.1){
                       d1[i,j] ="^{\\fns{*}}"}
                      else {
                          d1[i,j] = "\\hspace{0.2in}"}
                   
                   }
              kdim = kdim + 1
            }

write(sprintf("{"),file=tabfile,append=T)
write(sprintf("\\def\\sep{0.5em}"),file=tabfile,append=T)
write(sprintf("\\def\\fns{\\footnotesize}"),file=tabfile,append=T)
write(sprintf("\\begin{table}[!htbp]"),file=tabfile,append=T)
write(sprintf("\\centering"),file=tabfile,append=T)
write(sprintf("\\begin{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\caption{Probit Regression - Dependent Variable : $STAY$ }"),file=tabfile,append=T)
write(sprintf("\\smallskip"),file=tabfile,append=T)
write(sprintf("\\begin{tabular}{lllll}"),file=tabfile,append=T)
write(sprintf("\\toprule"),file=tabfile,append=T)
write(sprintf("\\multicolumn{5}{c}{ {Coefficient Estimate} } \\tabularnewline"),file=tabfile,append=T)
write(sprintf("\\multicolumn{5}{c}{ {\\fns(\\emph{t-stat.})}} \\tabularnewline"),file=tabfile,append=T)
write(sprintf("&  {(1)} &  {(2)}& {(3)} & {(4)}\\tabularnewline"),file=tabfile,append=T)
write(sprintf("\\midrule"),file=tabfile,append=T)
write(sprintf("{$\\delta$} 	   &   %s      &  %s &  %s &
               %s\\tabularnewline",paste0('$',sprintf("%.3f",zmat1$V1[2]),d1[2,1],'$'),paste0('$',sprintf("%.3f",zmat2$V1[2]),d1[2,2],'$'),paste0('$',sprintf("%.3f",zmat3$V1[2]),d1[2,3],'$'),paste0('$',sprintf("%.3f",zmat4$V1[2]),d1[2,4],'$')),file=tabfile,append=T)

write(sprintf("	&  \\fns{\\emph{(%.2f)}} & \\fns{\\emph{( %.2f)}} & \\fns{\\emph{(%.2f)}}&
\\fns{\\emph{(%.2f)}}\\tabularnewline[\\sep]",zmat1$V2[2],zmat2$V2[2],zmat3$V2[2],zmat4$V2[2]),file=tabfile,append=T)
write(sprintf("{$log(Y_{91-T})$}     &     &  %s &  %s &
               %s\\tabularnewline",paste0('$',sprintf("%.3f",zmat2$V1[3]),d1[3,2],'$'),paste0('$',sprintf("%.3f",zmat3$V1[3]),d1[3,3],'$'),paste0('$',sprintf("%.3f",zmat4$V1[3]),d1[3,4],'$')),file=tabfile,append=T)


write(sprintf("	                   &     &
              \\fns{\\emph{(%.2f)}}  &
              \\fns{\\emph{(%.2f)}}   &
              \\fns{\\emph{(%.2f)}} \\tabularnewline[\\sep]",zmat2$V2[3],zmat3$V2[3],zmat4$V2[3]),file=tabfile,append=T)
write(sprintf("	{$log(CRED)$}      &    &       &  %s &
               %s\\tabularnewline",paste0('$',sprintf("%.3f",zmat2$V1[4]),d1[4,2],'$'),paste0('$',sprintf("%.3f",zmat3$V1[4]),d1[4,3],'$'),paste0('$',sprintf("%.3f",zmat4$V1[4]),d1[4,4],'$')),file=tabfile,append=T)

write(sprintf("	 &     &       & \\fns{\\emph{(%.2f)}}
              &\\fns{\\emph{(%.2f)}}
              \\tabularnewline[\\sep]",zmat3$V2[4],zmat4$V2[4]),file=tabfile,append=T)
 write(sprintf("	{$SEX$}		              &     &       &   &
               %s\\tabularnewline",paste0('$',sprintf("%.3f",zmat4$V1[5]),d1[5,4],'$')),file=tabfile,append=T)
write(sprintf("					      &     &       &   &
\\fns{\\emph{(%.2f)}} \\tabularnewline[\\sep]",zmat4$V2[5]),file=tabfile,append=T)
write(sprintf(" {Intercept}  &   %s      &  %s &  %s &
               %s\\tabularnewline",paste0('$',sprintf("%.3f",zmat1$V1[1]),d1[1,1],'$'),paste0('$',sprintf("%.3f",zmat2$V1[1]),d1[1,2],'$'),paste0('$',sprintf("%.3f",zmat3$V1[1]),d1[1,3],'$'),paste0('$',sprintf("%.3f",zmat4$V1[1]),d1[1,4],'$')),file=tabfile,append=T)

write(sprintf(" & \\fns{\\emph{(%.2f)}}
&\\fns{\\emph{(%.2f)}}  &\\fns{\\emph{(%.2f)}}
&\\fns{\\emph{(%.2f)}}\\tabularnewline",zmat1$V2[1],zmat2$V2[1],zmat3$V2[1],zmat4$V2[1]),file=tabfile,append=T)
write(sprintf("\\bottomrule"),file=tabfile,append=T)
write(sprintf("\\end{tabular}"),file=tabfile,append=T)
write(sprintf("\\label{tab:regprobit}"),file=tabfile,append=T)
write(sprintf("\\begin{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\scriptsize"),file=tabfile,append=T)
write(sprintf("\\item\\emph{Notes}: The table reports coefficient
estimates (and estimated $t$-statistics in parentheses) from a Probit
regression of $STAY$ on the variables displayed on the first column.
$STAY$ is defined as 1 if a worker does not switch occupations and 0
otherwise.  $log(Y_{91-T})$ denotes initial earnings
(post-graduation), $SEX$ is defined as 1 if the worker is a female and
0 otherwise, $log(CRED)$ is the log of credits, $\\delta$ denotes our
measure of distance described in the text. Additional regressors
(coefficients not shown) are GPA and dummies for occupations, type of
degree, and major.Coefficient significantly different from zero at
least at the 0.1 level ({*}), at least at the 0.05 level ({**}), and 
at least at the 0.01 level ({***})."),file=tabfile,append=T)
write(sprintf("\\end{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\end{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\end{table}"),file=tabfile,append=T)
write(sprintf("}"),file=tabfile,append=T)

#_________________________________________________________________
# Moments for Estimation 
#_________________________________________________________________

occlabels <- c("Clerical", "Manager", "Skilled Op.", "Prof. - Arts","Prof. - Medical","Prof. - Eng.", "Prof. - Other", "Sales", "School Teacher", "Service", "Tech. Comp.", "Tech. Non Comp.")
occlabels <- c("Clerical", "Manager", "Skilled Operative",
"Professional - Arts","Professional - Medical","Professional - Engineering",
"Professional - Other", "Sales", "School Teacher", "Service",
"Technician - Computer-Related", "Technician - Non Computer-Related")

zmat <- read.table(paste0(pathtostruct,"struct_data_for_latex.txt"),header=F,
               sep="")
unlink(paste0(pathtodir,"moments_for_estimation.tex"),recursive=F,force=F)
tabfile =paste0(pathtodir,"moments_for_estimation.tex") 

write(sprintf("{"),file=tabfile,append=T)
write(sprintf("\\begin{table}[!htbp]\\centering"),file=tabfile,append=T)
write(sprintf("\\setlength{\\extrarowheight}{3.4pt}"),file=tabfile,append=T)
write(sprintf("\\begin{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\caption{Elements of the Vector $\\hat{\\Upsilon}$}"),file=tabfile,append=T)
write(sprintf("\\begin{tabular}{lcccc}"),file=tabfile,append=T)
write(sprintf(" & & & &\\tabularnewline"),file=tabfile,append=T)
write(sprintf("\\toprule"),file=tabfile,append=T)
write(sprintf(" {Occupation} &  {Sample Size} &  {$\\omega_H$} & {$\\omega_Q$} &  {\\%% Switch} \\tabularnewline"),file=tabfile,append=T)
write(sprintf("\\midrule"),file=tabfile,append=T)
for (i in seq(1,length(occlabels))){
 write(sprintf("%s & %d & %.3f (\\emph{%.3f})& %.3f (\\emph{%.3f}) & %.3f (\\emph{%.3f})\\tabularnewline",occlabels[i],zmat$V3[i],zmat$V1[i],zmat$V2[i], zmat$V1[i+length(occlabels)],zmat$V2[i+length(occlabels)],zmat$V1[i+2*length(occlabels)],zmat$V2[i+2*length(occlabels)]),file=tabfile,append=T)
}
write(sprintf("\\midrule"),file=tabfile,append=T)
write(sprintf(" &  {Sample Size} &   & & \\tabularnewline \\midrule"),file=tabfile,append=T)
write(sprintf(" {Standard Deviation (Log) Earnings } &  &	 &	 & \\tabularnewline"),file=tabfile,append=T)
write(sprintf("{First Period} & %s & %.3f	 (\\emph{%.3f}) &	 &
              \\tabularnewline ", comma(zmat$V3[40]),zmat$V1[40],zmat$V2[40] ),file=tabfile,append=T)

write(sprintf("{Standard Deviation $\\omega_H$} & %s & %.3f 
              (\\emph{%.3f})	 &	 &	 \\tabularnewline",
              comma(zmat$V3[37]),zmat$V1[37],zmat$V2[37]),file=tabfile,append=T)
write(sprintf("{Standard Deviation $\\omega_Q$} & %s & %.3f 
              (\\emph{%.3f})	 &	 &	 \\tabularnewline",
              comma(zmat$V3[38]),zmat$V1[38],zmat$V2[38]),file=tabfile,append=T)
write(sprintf("{Standard Deviation $\\omega_SS$} & %s & %.3f 
              (\\emph{%.3f})	 &	 &	 \\tabularnewline",
              comma(zmat$V3[39]),zmat$V1[39],zmat$V2[39]),file=tabfile,append=T)



 write(sprintf("{\\%%``Stay-Switch Events''} & %s & %.3f  (\\emph{%.3f}) &	 &
 \\tabularnewline",comma(zmat$V3[41]),zmat$V1[41], zmat$V2[41]),file=tabfile,append=T)
  
 write(sprintf("{$\\rho(CRED_{SS},CRED_{Q})$} & %s & %.3f  (\\emph{%.3f}) &	 &
 \\tabularnewline",comma(zmat$V3[42]),zmat$V1[42],zmat$V2[42]),file=tabfile,append=T)

  write(sprintf("{$\\rho(CRED_{SS},CRED_{H})$} & %s &  %.3f (\\emph{%.3f}) &	 &
 \\tabularnewline",comma(zmat$V3[43]),zmat$V1[43],zmat$V2[43]),file=tabfile,append=T)

  write(sprintf("{$\\rho(CRED_{H},CRED_{Q})$} & %s &  %.3f (\\emph{%.3f}) &	 &
 \\tabularnewline",comma(zmat$V3[44]),zmat$V1[44],zmat$V2[44]),file=tabfile,append=T)

  write(sprintf("{Switching Rate} & %s &  %.3f (\\emph{%.3f}) &	 &
 \\tabularnewline",comma(zmat$V3[45]),zmat$V1[45],zmat$V2[45]),file=tabfile,append=T)
 
write(sprintf("\\bottomrule"),file=tabfile,append=T)
write(sprintf("\\end{tabular}"),file=tabfile,append=T)
write(sprintf("\\label{tab:moments}"),file=tabfile,append=T)
write(sprintf("\\begin{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\scriptsize"),file=tabfile,append=T)
write(sprintf("\\item \\emph{Notes}: Each cell reports a sample moment, either a mean or a
standard deviation, and in parentheses an estimate of the standard deviation of
that sample moment. In the upper panel we report, for each occupation, the mean
portfolio shares in Humanities and Quantitative Skills, and the fraction of
Switchers in the first period. In the lower panel, we report the standard
deviations of (Log) Earnings in the initial period, the cross-sectional standard
deviation for the portfolio shares in each skill type, the fraction of
``Stay-Switch Events'' (see main text for an explanation of how the statistic is
computed), the cross-sectional correlations among the different human capital
types, and the overall Switching Rate. We also report the sample size used to compute each sample moment."),file=tabfile,append=T)
write(sprintf("\\end{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\end{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\end{table}"),file=tabfile,append=T)
write(sprintf("}"),file=tabfile,append=T)

#_________________________________________________________________
# Estimation results table
#_________________________________________________________________

unlink(paste0(pathtodir,"estimation_results.tex"),recursive=F,force=F)
tabfile =paste0(pathtodir,"estimation_results.tex") 
estimates <- read.table(paste0(pathtofortran,"initguess_weighted.txt"),header=F)
stderr <-read.table(paste0(pathtofortran,"standard_errors.txt"),header=T)

write(sprintf("{"),file=tabfile,append=T)
write(sprintf("\\begin{table}[!htbp]\\centering"),file=tabfile,append=T)
write(sprintf("\\setlength{\\extrarowheight}{3.4pt}"),file=tabfile,append=T)
write(sprintf("\\begin{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\caption{Estimation Results}"),file=tabfile,append=T)
write(sprintf("\\begin{tabular}{lccc}"),file=tabfile,append=T)
write(sprintf("& & & \\tabularnewline"),file=tabfile,append=T)
write(sprintf("\\toprule"),file=tabfile,append=T)
write(sprintf("{Occupation} &   {$\\hat{\\alpha}_H$}&  {$\\hat{\\alpha}_Q$} &
{$\\hat{\\sigma}_\\epsilon$} \\tabularnewline"),file=tabfile,append=T)
write(sprintf("\\midrule"),file=tabfile,append=T)
for (i in seq(1,length(occlabels))){ 
write(sprintf(" {%s} &    %.3f (\\emph{%.3f})&     %.3f (\\emph{%.3f})
              &  %.3f (\\emph{%.3f})
              \\tabularnewline",occlabels[i],estimates$V1[i],stderr$x[i],estimates$V1[i+length(occlabels)],stderr$x[i+length(occlabels)],estimates$V1[i+2*length(occlabels)],stderr$x[i+2*length(occlabels)]),file=tabfile,append=T)
}
write(sprintf("\\midrule"),file=tabfile,append=T)
write(sprintf("&  {Estimate (\\emph{Std. Error})} &
              \\tabularnewline"),file=tabfile,append=T)
write(sprintf(" \\midrule"),file=tabfile,append=T)
write(sprintf("{$\\sigma_\\theta$} &  %.3f(\\emph{%.3f})   &
              \\tabularnewline", estimates$V1[40],stderr$x[40] ),file=tabfile,append=T)
write(sprintf("{$\\sigma^2_{\\xi_{H}}$} & %.3f  (\\emph{%.3f}) &
              \\tabularnewline",estimates$V1[37],stderr$x[37]),file=tabfile,append=T)
write(sprintf("{$\\sigma^2_{\\xi_{Q}}$} & %.3f (\\emph{%.3f})  &
              \\tabularnewline",estimates$V1[38],stderr$x[38]),file=tabfile,append=T)
write(sprintf("{$\\sigma^2_{\\xi_{SS}}$} & %.3f  (\\emph{%.3f})  &
              \\tabularnewline",estimates$V1[39],stderr$x[39]),file=tabfile,append=T)
write(sprintf("{$\\pi$} & %.3f (\\emph{%.3f})  &
              \\tabularnewline",estimates$V1[41],stderr$x[41]),file=tabfile,append=T)
write(sprintf("{$\\rho_{\\xi}$} & %.3f (\\emph{%.3f})  &
              \\tabularnewline",estimates$V1[42],stderr$x[42]),file=tabfile,append=T)

write(sprintf("\\bottomrule"),file=tabfile,append=T)
write(sprintf("\\label{tab:estimates}"),file=tabfile,append=T)
write(sprintf("\\end{tabular}"),file=tabfile,append=T)
write(sprintf("\\begin{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\scriptsize"),file=tabfile,append=T)
write(sprintf("\\item \\emph{Notes}: This table reports the estimated value for each element in
the vector of structural parameters $\\hat{\\Lambda}$. In parentheses, we report
numerical standard errors computed using \\eqref{eq:stderror}."),file=tabfile,append=T)
write(sprintf("\\end{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\end{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\end{table}"),file=tabfile,append=T)
write(sprintf("}"),file=tabfile,append=T)

#_________________________________________________________________
# Income Growth Distribution Summary 
#_________________________________________________________________

unlink(paste0(pathtodir,"income_growth_summary.tex"),recursive=F,force=F)
tabfile =paste0(pathtodir,"income_growth_summary.tex") 
filemodel <- paste0("_table_weighted_cd.txt")
zmodel1 <- read.table(file=paste0(pathtodata,"model_reg1_",filemodel),header=T,sep=",") 


# load summary data: order: SD, min, 1Q, Med, Mean,3Q,Max,Skew,Kurt)
data_summary <- read.table(file=paste0(pathtodata,"Summary_data_incgrowth.txt"),header=F, sep="")
model_summary <-
    read.table(file=paste0(pathtodata,"Summary_model_incgrowth_weighted_cd.txt"),header=F, sep="")
 
write(sprintf("{"),file=tabfile,append=T)
write(sprintf("\\begin{table}[!htbp]"),file=tabfile,append=T)
write(sprintf("\\centering"),file=tabfile,append=T)
write(sprintf("\\begin{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\baselineskip=55mm"),file=tabfile,append=T)
write(sprintf("\\caption{Income Growth Distribution Summary - Model vs. Data}"),file=tabfile,append=T)
write(sprintf("\\begin{tabular}{lccccc}"),file=tabfile,append=T)
write(sprintf("\\toprule"),file=tabfile,append=T)
write(sprintf("       &  {Min.}   &  {1st. Quart.} &   {Median}  &  {Mean} &
          {3rd Quart.} \\tabularnewline"),file=tabfile,append=T)
write(sprintf("\\midrule"),file=tabfile,append=T)
write(sprintf(" {Data}    & %.3f  & %.3f & %.3f & %.3f & %.3f
              \\tabularnewline",data_summary$V2[2],data_summary$V2[3],data_summary$V2[4],data_summary$V2[5],data_summary$V2[6]),file=tabfile,append=T)
write(sprintf("{Model}   & %.3f & %.3f & %.3f & %.3f & %.3f
              \\tabularnewline",model_summary$V2[2],model_summary$V2[3],model_summary$V2[4],model_summary$V2[5],model_summary$V2[6]),file=tabfile,append=T)
 
write(sprintf("\\bottomrule"),file=tabfile,append=T)
write(sprintf("\\smallskip"),file=tabfile,append=T)
write(sprintf("\\end{tabular}"),file=tabfile,append=T)
write(sprintf("\\begin{tabular}{lcccc}"),file=tabfile,append=T)
write(sprintf("\\toprule"),file=tabfile,append=T)

write(sprintf("       &  {Max.} &   {Std. Dev.} &  {Skew.} &
          {Kurt.} \\tabularnewline"),file=tabfile,append=T)
write(sprintf("\\midrule"),file=tabfile,append=T)
write(sprintf("{Data}    &%.3f  & %.3f & %.3f & %.3f
              \\tabularnewline",data_summary$V2[7],data_summary$V2[1],data_summary$V2[8],data_summary$V2[9]),file=tabfile,append=T)
write(sprintf("{Model}   & %.3f & %.3f & %.3f & %.3f\\tabularnewline",model_summary$V2[7],model_summary$V2[1],model_summary$V2[8],model_summary$V2[9]),file=tabfile,append=T)

write(sprintf("\\bottomrule"),file=tabfile,append=T)
write(sprintf("\\end{tabular}"),file=tabfile,append=T)
write(sprintf("\\label{tab:incgrowthdist}"),file=tabfile,append=T)

write(sprintf("\\begin{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\scriptsize"),file=tabfile,append=T)
write(sprintf("\\item \\emph{Notes}: The table compares several
              statistics of interest of the income growth
distribution found in the HS\\&B dataset with a model-simulated (%s individuals)
income growth distribution. The sample of students used to compute the Data
moments are the same %s individuals reported in Table
\\ref{tab:moments}.",comma(zmodel1$V3[1]),comma(zmat$V3[43])),file=tabfile,append=T)
write(sprintf("\\end{tablenotes}"),file=tabfile,append=T)

write(sprintf("\\end{threeparttable}"),file=tabfile,append=T)

write(sprintf("\\end{table}"),file=tabfile,append=T)
write(sprintf("}"),file=tabfile,append=T)

#_________________________________________________________________
# Model OLS regression results 
#_________________________________________________________________

filename <- paste0("_table_without_arts_weighted_GPA_major.txt")
filemodel <- paste0("_table_weighted_cd.txt")

zmodel1 <- read.table(file=paste0(pathtodata,"model_reg1_",filemodel),header=T,sep=",") 
zmodel4 <- read.table(file=paste0(pathtodata,"model_reg3_",filemodel),header=T,sep=",")

zdata1 <- read.table(file=paste0(pathtodata,"reg1_",filename),header=T,sep=",") 
zdata2 <- read.table(file=paste0(pathtodata,"reg2_",filename),header=T,sep=",") 
zdata3 <- read.table(file=paste0(pathtodata,"reg3_",filename),header=T,sep=",") 
zdata4 <- read.table(file=paste0(pathtodata,"reg4_",filename),header=T,sep=",")

# matrix to summarize significance levels (to print significance stars
# in tables)

d1 <- matrix(as.character(mat.or.vec(dim(zdata4)[1],4)),nrow=dim(zdata4)[1],ncol=4)
pvalmat <- matrix(mat.or.vec(dim(zdata4)[1],4),nrow=dim(zdata4)[1],ncol=4)
pvalmat[1:dim(zdata1)[1],1] <- zdata1[,5]
pvalmat[1:dim(zdata2)[1],2] <- zdata2[,5]
pvalmat[1:dim(zdata3)[1],3] <- zdata3[,5]
pvalmat[1:dim(zdata4)[1],4] <- zdata4[,5]

#pvalmat <- as.numeric(pvalmat)
kdim = dim(zdata1)[1]
for (j in seq(1,4)){

       for (i in seq(1,kdim)){
                      if (pvalmat[i,j]<0.01) { 
                       d1[i,j] ="^{\\fns{***}}"}
                      else if (pvalmat[i,j]>0.01&pvalmat[i,j]<0.05){
                       d1[i,j] ="^{\\fns{**}}"}
                      else if (pvalmat[i,j]>0.05&pvalmat[i,j]<0.1){
                       d1[i,j] ="^{\\fns{*}}"}
                      else {
                          d1[i,j] = "\\hspace{0.2in}"}
                   
                   }
              kdim = kdim + 1
            }

unlink(paste0(pathtodir,"ols_model_reg_table.tex"),recursive=F,force=F)
tabfile =paste0(pathtodir,"ols_model_reg_table.tex") 

write(sprintf("{"),file=tabfile,append=T)
write(sprintf("\\def\\sep{0.5em}"),file=tabfile,append=T)
write(sprintf("\\def\\sepo{0.01em}"),file=tabfile,append=T)
write(sprintf("\\begin{table}[!htbp]"),file=tabfile,append=T)
write(sprintf("\\centering"),file=tabfile,append=T)
write(sprintf("\\begin{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\baselineskip=55mm"),file=tabfile,append=T)
write(sprintf("\\caption{Regression Results - Model-Simulated Final Wage ($log(Y_{91})$)}"),file=tabfile,append=T)
write(sprintf("\\smallskip"),file=tabfile,append=T)
write(sprintf("\\begin{tabular}{lllll}"),file=tabfile,append=T)
write(sprintf("\\toprule"),file=tabfile,append=T)
write(sprintf("& \\multicolumn{2}{l}{ {Model}} & \\multicolumn{2}{l}{ {Data} } \\tabularnewline"),file=tabfile,append=T)
write(sprintf("&  {(1)} &  {(2)}&  {(1)}&  {(2)}\\tabularnewline"),file=tabfile,append=T)
write(sprintf("\\midrule"),file=tabfile,append=T)
write(sprintf("{$log(Y_{91-T})$} & %.3f &  %.3f &  %s & %s \\tabularnewline", zmodel1$V1[2], zmodel4$V1[2] ,paste0('$',sprintf("%.3f",zdata1$V1[2]),d1[2,1],'$'),paste0('$',sprintf("%.3f",zdata4$V1[2]),d1[2,4],'$')),file=tabfile,append=T)
write(sprintf("&  &   &\\fns{\\emph{(%.2f)}} & \\fns{\\emph{(%.2f)}} \\tabularnewline[\\sep]",  zdata1$V2[2], zdata4$V2[2]),file=tabfile,append=T)
write(sprintf("{$log(CRED)$}  & %.3f &  %.3f &  %s & %s\\tabularnewline", zmodel1$V1[3], zmodel4$V1[3], paste0('$',sprintf("%.3f",zdata1$V1[3]),d1[3,1],'$'),paste0('$',sprintf("%.3f",zdata4$V1[3]),d1[3,4],'$')),file=tabfile,append=T)

write(sprintf("&  &   &\\fns{\\emph{(%.2f)}} & \\fns{\\emph{(%.2f)}} \\tabularnewline[\\sep]",  zdata1$V2[3], zdata4$V2[3]),file=tabfile,append=T)

write(sprintf("{$\\delta$}  &  %.3f &  %.3f &  %s & %s \\tabularnewline", zmodel1$V1[4], zmodel4$V1[4], paste0('$',sprintf("%.3f",zdata1$V1[5]),d1[5,1],'$'),paste0('$',sprintf("%.3f",zdata4$V1[5]),d1[5,4],'$')),file=tabfile,append=T)

write(sprintf("& &               &\\fns{\\emph{(%.2f)}} &
              \\fns{\\emph{(%.2f)}}
              \\tabularnewline[\\sep]", 
              zdata1$V2[5], zdata4$V2[5]),file=tabfile,append=T)

write(sprintf("{$CAREER$}  &  & %.3f  &  & %s \\tabularnewline",
              zmodel4$V1[7],paste0('$',sprintf("%.3f",zdata4$V1[7]),d1[7,4],'$')),file=tabfile,append=T)

write(sprintf("&  &   & & \\fns{\\emph{(%.2f)}} \\tabularnewline[\\sep]",  zdata4$V2[7]),file=tabfile,append=T)

write(sprintf("{$STAY$}    &  & %.3f  &   & %s
              \\tabularnewline", zmodel4$V1[5],
              paste0('$',sprintf("%.3f",zdata4$V1[6]),d1[6,4],'$')),file=tabfile,append=T)

 write(sprintf("&  &  
              & & \\fns{\\emph{(%.2f)}}
              \\tabularnewline[\\sep]" ,
               zdata4$V2[6]),file=tabfile,append=T)

write(sprintf("{$\\delta\\times STAY$}    &  & %.3f  &   & %s \\tabularnewline", zmodel4$V1[6],
               paste0('$',sprintf("%.3f",zdata4$V1[8]),d1[8,4],'$')),file=tabfile,append=T)

write(sprintf("&  &  
              && \\fns{\\emph{(%.2f)}}
              \\tabularnewline[\\sep]", 
               zdata4$V2[8]),file=tabfile,append=T)
write(sprintf(" {Intercept} & %.3f &  %.3f &  %s & %s\\tabularnewline", zmodel1$V1[1],zmodel4$V1[1],paste0('$',sprintf("%.3f",zdata1$V1[1]),d1[1,1],'$'),paste0('$',sprintf("%.3f",zdata4$V1[1]),d1[1,4],'$')),file=tabfile,append=T)
write(sprintf("&&  
              &\\fns{\\emph{(%.2f)}} & \\fns{\\emph{(%.2f)}}
              \\tabularnewline[\\sep]", 
              zdata1$V2[1], zdata4$V2[1]),file=tabfile,append=T)

write(sprintf("\\midrule"),file=tabfile,append=T)
write(sprintf("{$N$} & %s & %s & %s & %s\\tabularnewline",
              comma(zmodel1$V3[1]), comma(zmodel4$V3[1]),
              comma(zdata1$V3[1]), comma(zdata4$V3[1])),file=tabfile,append=T)
write(sprintf("{$R^2$} & %.3f &  %.3f  & %.3f & %.3f
              \\tabularnewline",zmodel1$V4[1], zmodel4$V4[1],
              zdata1$V4[1], zdata4$V4[1]),file=tabfile,append=T)
write(sprintf("\\bottomrule"),file=tabfile,append=T)
write(sprintf("\\end{tabular}"),file=tabfile,append=T)
write(sprintf("\\label{tab:regsimple_model}"),file=tabfile,append=T)
write(sprintf("\\begin{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\scriptsize"),file=tabfile,append=T)
write(sprintf("\\item \\emph{Notes}: The table reports coefficient
estimates (and estimated $t$-statistics in parentheses) from
an OLS regression of final earnings ($log(Y_{91}))$ on the variables
displayed on the first column. $log(Y_{91-T})$ denotes initial
earnings, $log(CRED)$ is the log of credits (in the model this
variable is calculated as $log(\\sum_{k=1}^K h_k)$), $\\delta$
denotes our measure of distance described in the text, and $STAY$ is
defined as 1 if a worker does not switch occupations and 0 otherwise.
The first two colums report values found using model-simulated data
and the last two columns correspond to columns 1 and 4 of Table
\\ref{tab:regsimple}. Coefficient significantly different from zero at
least at the 0.1 level ({*}), at least at the 0.05 level ({**}), and
at least at the 0.01 level ({***}). "),file=tabfile,append=T)
write(sprintf("\\end{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\end{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\end{table}"),file=tabfile,append=T)
write(sprintf("}"),file=tabfile,append=T)

#_________________________________________________________________
# Model Probit regression results 
#_________________________________________________________________

filename <- paste0("_table_without_arts_weighted_GPA_major.txt")
filemodel <- paste0("_table_weighted_cd.txt")

zmodel1 <- read.table(file=paste0(pathtodata,"model_probit1_",filemodel),header=T,sep=",") 
zmodel4 <- read.table(file=paste0(pathtodata,"model_probit2_",filemodel),header=T,sep=",")

zdata1 <- read.table(file=paste0(pathtodata,"probit1_",filename),header=T,sep=",") 
zdata2 <- read.table(file=paste0(pathtodata,"probit2_",filename),header=T,sep=",") 
zdata3 <- read.table(file=paste0(pathtodata,"probit3_",filename),header=T,sep=",") 
zdata4 <- read.table(file=paste0(pathtodata,"probit4_",filename),header=T,sep=",")

# matrix to summarize significance levels (to print significance stars
# in tables)

d1 <- matrix(as.character(mat.or.vec(dim(zdata4)[1],4)),nrow=dim(zdata4)[1],ncol=4)
pvalmat <- matrix(mat.or.vec(dim(zdata4)[1],4),nrow=dim(zdata4)[1],ncol=4)

pvalmat[1:dim(zdata1)[1],1] <- zdata1[,4]
pvalmat[1:dim(zdata2)[1],2] <- zdata2[,4]
pvalmat[1:dim(zdata3)[1],3] <- zdata3[,4]
pvalmat[1:dim(zdata4)[1],4] <- zdata4[,4]

kdim = dim(zdata1)[1]
for (j in seq(1,4)){

       for (i in seq(1,kdim)){
                      if (pvalmat[i,j]<0.01) { 
                       d1[i,j] ="^{\\fns{***}}"}
                      else if (pvalmat[i,j]>0.01&pvalmat[i,j]<0.05){
                       d1[i,j] ="^{\\fns{**}}"}
                      else if (pvalmat[i,j]>0.05&pvalmat[i,j]<0.1){
                       d1[i,j] ="^{\\fns{*}}"}
                      else {
                          d1[i,j] = "\\hspace{0.2in}"}
                   
                   }
              kdim = kdim + 1
            }

unlink(paste0(pathtodir,"probit_model_reg_table.tex"),recursive=F,force=F)
tabfile =paste0(pathtodir,"probit_model_reg_table.tex") 

write(sprintf("{"),file=tabfile,append=T)
write(sprintf("\\begin{table}[!htbp]"),file=tabfile,append=T)
write(sprintf("\\centering"),file=tabfile,append=T)
write(sprintf("\\begin{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\caption{Probit Regression Results - Model-Simulated Occupational Stayers vs.
Switchers ($STAY$)}"),file=tabfile,append=T)
write(sprintf("\\smallskip"),file=tabfile,append=T)
write(sprintf("\\begin{tabular}{lllll}"),file=tabfile,append=T)
write(sprintf("\\toprule"),file=tabfile,append=T)
write(sprintf("& \\multicolumn{2}{l}{ {Model}} & \\multicolumn{2}{l}{ {Data} } \\tabularnewline"),file=tabfile,append=T)
write(sprintf("&  {(1)} &  {(2)}&  {(1)}&  {(2)}\\tabularnewline"),file=tabfile,append=T)
write(sprintf("\\midrule"),file=tabfile,append=T)
write(sprintf("{$\\delta$} &	%.3f &  %.3f &  %s & %s \\tabularnewline", zmodel1$V1[2], zmodel4$V1[2],  paste0('$',sprintf("%.3f",zdata1$V1[2]),d1[2,2],'$'),paste0('$',sprintf("%.3f",zdata4$V1[2]),d1[2,4],'$')),file=tabfile,append=T)

write(sprintf("& &  
              &\\fns{\\emph{(%.2f)}} & \\fns{\\emph{(%.2f)}}
              \\tabularnewline[\\sep]", 
              zdata1$V2[2], zdata4$V2[2]),file=tabfile,append=T)
write(sprintf("{$log(Y_{91-T})$} & & %.3f & & %s
              \\tabularnewline",zmodel4$V1[3],paste0('$',sprintf("%.3f",zdata4$V1[3]),d1[3,4],'$')),file=tabfile,append=T)

write(sprintf("         &   &  &   &
              \\fns{\\emph{(%.2f)}}
\\tabularnewline[\\sepo]",zdata4$V2[3]),file=tabfile,append=T)
write(sprintf("{Intercept}  & %.3f &  %.3f & %s & %s\\tabularnewline",
              zmodel1$V1[1], zmodel4$V1[1],paste0('$',sprintf("%.3f",zdata1$V1[1]),d1[1,1],'$'),paste0('$',sprintf("%.3f",zdata4$V1[1]),d1[1,4],'$')),file=tabfile,append=T)
write(sprintf("& &   &\\fns{\\emph{(%.2f)}} & \\fns{\\emph{(%.2f)}}
              \\tabularnewline[\\sep]", 
              zdata1$V2[1], zdata4$V2[1]),file=tabfile,append=T)
write(sprintf("\\midrule"),file=tabfile,append=T)
write(sprintf("{$N$}  & %s & %s & %s & %s\\tabularnewline",
              comma(zmodel1$V3[1]), comma(zmodel4$V3[1]),
              comma(zdata1$V3[1]), comma(zdata4$V3[1])),file=tabfile,append=T)
write(sprintf("\\bottomrule"),file=tabfile,append=T)
write(sprintf("\\end{tabular}"),file=tabfile,append=T)
write(sprintf("\\label{tab:probit_model}"),file=tabfile,append=T)
write(sprintf("\\begin{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\scriptsize"),file=tabfile,append=T)
write(sprintf("\\item \\emph{Notes}: The table reports coefficient
estimates (and estimated $t$-statistics in parentheses) from
a Probit regression of $STAY$ on the  variables displayed on the first
column. $STAY$ is defined as 1 if a worker does not switch occupations
and 0 otherwise.  $log(Y_{91-T})$ denotes initial earnings, and
$\\delta$ denotes our measure of distance described in the text.  The
first two colums reflect values found in model-simulated data and the
last two columns correspond to the first two columns of Table
\\ref{tab:regprobit}. Coefficient significantly different from zero at
least at the 0.1 level ({*}), at least at the 0.05 level ({**}), and
at least at the 0.01 level ({***}).  "),file=tabfile,append=T)
write(sprintf("\\end{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\end{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\end{table}"),file=tabfile,append=T)
write(sprintf("}"),file=tabfile,append=T)

#_________________________________________________________________
# Counterfactual Experiments Table 
#_________________________________________________________________
data_nouncert <- read.table(paste0(pathtodata,"exp_data_counterfactual_nouncert.txt"))
data_weighted <- read.table(paste0(pathtodata,"exp_data_weighted_cd.txt"))
data_counterf <- read.table(paste0(pathtodata,"exp_data_counterfactual_cd.txt"))

unlink(paste0(pathtodir,"counterfactual_experiment_table.tex"),recursive=F,force=F)
tabfile =paste0(pathtodir,"counterfactual_experiment_table.tex") 

write(sprintf("{"),file=tabfile,append=T)
write(sprintf("\\def\\sep{0.5em}"),file=tabfile,append=T)
write(sprintf("\\begin{table}[!htbp]"),file=tabfile,append=T)
write(sprintf("\\centering"),file=tabfile,append=T)
write(sprintf("\\setlength{\\extrarowheight}{2.0pt}"),file=tabfile,append=T)
write(sprintf("\\begin{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\caption{Baseline and Counterfactual Earnings Distributions
\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\,\\
}\\label{tab:earningsdists}"),file=tabfile,append=T)
write(sprintf("\\smallskip"),file=tabfile,append=T)
write(sprintf("\\footnotesize"),file=tabfile,append=T)
write(sprintf("\\begin{tabular}{rrcccccc}"),file=tabfile,append=T)
write(sprintf("\\toprule"),file=tabfile,append=T)
write(sprintf("& & {$\\%% Switchers$}& $Earnings$  &  $Earnings$  &
              $Earnings$
              &  $p(99)/p(50)$  & $Cost$  \\tabularnewline"),file=tabfile,append=T)
write(sprintf("& & & $(Level)$ &  $(Growth)$ & 
              $(Gini)$ &  & \\tabularnewline"),file=tabfile,append=T)

              write(sprintf("\\midrule"),file=tabfile,append=T)

write(sprintf("{Baseline} & All &%.1f  & %.3f &  %.3f & %.3f & %.3f &
              %.3f \\tabularnewline
              [\\sep]",data_weighted$V2[16]*100,exp(data_weighted$V2[1]),data_weighted$V2[3],data_weighted$V2[2],data_weighted$V2[5],data_weighted$V2[17]),file=tabfile,append=T)
write(sprintf("{} & Non-Switchers &  &%.3f  & %.3f &  %.3f & %.3f & %.3f
              \\tabularnewline[\\sep]",exp(data_weighted$V2[6]),data_weighted$V2[8],data_weighted$V2[7],data_weighted$V2[10],data_weighted$V2[18]),file=tabfile,append=T)
write(sprintf("{} & Switchers & & %.3f  & %.3f &  %.3f & %.3f &  %.3f
              \\tabularnewline[\\sep]",exp(data_weighted$V2[11]),data_weighted$V2[13],data_weighted$V2[12],data_weighted$V2[15],data_weighted$V2[19]),file=tabfile,append=T)

write(sprintf("\\midrule"),file=tabfile,append=T)
write(sprintf("\\multicolumn{8}{c}{\\%% Change from Baseline } \\tabularnewline"),file=tabfile,append=T)

write(sprintf("\\midrule"),file=tabfile,append=T)
write(sprintf("{No Uncertainty} & All & %.1f  & %.1f &  %.1f & %.1f &
              %.1f & %.1f\\tabularnewline[\\sep]",(data_nouncert$V2[16]/data_weighted$V2[16]-1)*100,(exp(data_nouncert$V2[1])/exp(data_weighted$V2[1])-1)*100,(data_nouncert$V2[3]/data_weighted$V2[3]-1)*100,(data_nouncert$V2[2]/data_weighted$V2[2]-1)*100,(data_nouncert$V2[5]/data_weighted$V2[5]-1)*100,(data_nouncert$V2[5]/data_weighted$V2[5]-1)*100,(data_nouncert$V2[17]/data_weighted$V2[17]-1)*100),file=tabfile,append=T)
write(sprintf(" & Non-Switchers & &%.1f  & %.1f &  %.1f & %.1f & %.1f 

              \\tabularnewline
              [\\sep]",(exp(data_nouncert$V2[6])/exp(data_weighted$V2[6])-1)*100,(data_nouncert$V2[8]/data_weighted$V2[8]-1)*100,(data_nouncert$V2[7]/data_weighted$V2[7]-1)*100,(data_nouncert$V2[10]/data_weighted$V2[10]-1)*100,(data_nouncert$V2[18]/data_weighted$V2[18]-1)*100),file=tabfile,append=T)
write(sprintf(" & Switchers & & -  & - &  - & - & - 
              \\tabularnewline
              [\\sep]"),file=tabfile,append=T)
write(sprintf("\\midrule"),file=tabfile,append=T)
write(sprintf("{Specialization} & All &%.1f  & %.1f &  %.1f & %.1f & %.1f& %.1f 

              \\tabularnewline[\\sep]",(data_counterf$V2[16]/data_weighted$V2[16]-1)*100,(exp(data_counterf$V2[1])/exp(data_weighted$V2[1])-1)*100,(data_counterf$V2[3]/data_weighted$V2[3]-1)*100,(data_counterf$V2[2]/data_weighted$V2[2]-1)*100,(data_counterf$V2[5]/data_weighted$V2[5]-1)*100,(data_counterf$V2[17]/data_weighted$V2[17]-1)*100),file=tabfile,append=T)
write(sprintf(" & Non-Switchers & &%.1f  & %.1f &  %.1f & %.1f & %.1f 
              \\tabularnewline[\\sep]",(exp(data_counterf$V2[6])/exp(data_weighted$V2[6])-1)*100,(data_counterf$V2[8]/data_weighted$V2[8]-1)*100,(data_counterf$V2[7]/data_weighted$V2[7]-1)*100,(data_counterf$V2[10]/data_weighted$V2[10]-1)*100,(data_counterf$V2[18]/data_weighted$V2[18]-1)*100),file=tabfile,append=T)
write(sprintf(" & Switchers & &%.1f  & %.1f &  %.1f & %.1f & %.1f 
              \\tabularnewline[\\sep]",(exp(data_counterf$V2[11])/exp(data_weighted$V2[11])-1)*100,(data_counterf$V2[13]/data_weighted$V2[13]-1)*100,(data_counterf$V2[12]/data_weighted$V2[12]-1)*100,(data_counterf$V2[15]/data_weighted$V2[15]-1)*100,(data_counterf$V2[19]/data_weighted$V2[19]-1)*100),file=tabfile,append=T)

              
write(sprintf("\\bottomrule"),file=tabfile,append=T)
write(sprintf("\\end{tabular}"),file=tabfile,append=T)
write(sprintf("\\begin{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\scriptsize"),file=tabfile,append=T)
write(sprintf("\\item \\emph{Notes}: The table reports selected moments from
three model simulations. The upper panel (``Baseline'') corresponds to
simulations using our estimated parameters and the model
described in the text. The middle panel (`` No Uncertainty'')
corresponds to the case in which individuals choose
portfolios under the knowledge of $\\theta$ and
$\\epsilon$. The lower panel (``Specialization'')
correponds to the case in which individuals with
specialized portfolios experience the labor market of
the ``Baseline'' scenario. $p(99)/p(50)$ denotes the ratio
of the 99th percentile to the median of the earnings
distribution. All model-generated distributions come from the same cross-section of
%s individuals.",comma(zmodel1$V3[1])),file=tabfile,append=T)
write(sprintf("\\end{tablenotes}"),file=tabfile,append=T)
write(sprintf("\\end{threeparttable}"),file=tabfile,append=T)
write(sprintf("\\end{table}"),file=tabfile,append=T)
write(sprintf("}"),file=tabfile,append=T)

