rm(list=ls())
# load necesary libraries
library(doBy)
library(gdata)
library(Hmisc)
library(moments)
library(dummies)
library(ineq)


pathtodir = "../HKP_Data_Regression_Results/" 
pathtofortran = "../HKP_Fortran_Code/" 

labelvec <-  c('weighted_cd','counterfactual_cd','counterfactual_nouncert')

for (i in seq(1,length(labelvec))){

    test<-read.table(paste0(pathtofortran,"result_",labelvec[i],".txt"),header=F, sep="", as.is=T)
    
    # label variables
    names(test)[1] <- "occ1"
    names(test)[2] <- "occ87"
    names(test)[3] <- "occ88"
    names(test)[4] <- "occ89"
    names(test)[5] <- "occ2"
    names(test)[6] <- "incgr"
    names(test)[7] <- "inc1"
    names(test)[8] <- "w1"
    names(test)[9] <- "w2"
    names(test)[10]<- "w3"
    names(test)[11]<-"credits"
    names(test)[12]<-"incinf"
    names(test)[13] <- "cost"

    #---------------------------------------------------------------------------------
    # Compute average weights by occupation
    #---------------------------------------------------------------------------------
    test$cost <- as.numeric(test$cost)
    test$occinit <- test$occ1
    test$occend <-  test$occ2
    
    # occupation codes to compute CAREER are different because occs 7 and
    # 8 are removed. So, for example occupation 9 in the main code is now
    # 7.
    test$icareer <- ifelse((test$occ1==1&test$occ2==2)|(test$occ1==1&test$occ2==7)|
    (test$occ1==7&test$occ2==2)|(test$occ1==6&test$occ2==2)|
    (test$occinit==10&test$occ2==2),1,0)
    
    test_noswitch<-test[(test$occ1==test$occ87)&(test$occ87==test$occ88)&
                        (test$occ88==test$occ89)&(test$occ89==test$occ2),] 
    
    aggport_model<-summaryBy(w1+w2+w3~occ1,data=test_noswitch,FUN=c(mean,sd))
    aggport_model$occinit <- aggport_model$occ1
    dim(aggport_model)
    aggport_model<-aggport_model[,2:8]
    
    #---------------------------------------------------------------------------------
    # MERGE THE TWO DATATSETS
    #---------------------------------------------------------------------------------
    test<-merge(test,aggport_model,by.x = "occinit",by.y = "occinit")
    
    test$diver_agg<-sqrt ( (test$w1-test$w1.mean)^2+(test$w2-test$w2.mean)^2+(test$w3-test$w3.mean)^2 )
    test$diver<-test$diver_agg
    
    test<-rename.vars(test, c("w1.mean","w2.mean","w3.mean"), c("w1_init","w2_init","w3_init"),info=TRUE)
    
    test<-remove.vars(test, c("w1.mean","w2.mean","w3.mean",
    "w1.sd","w2.sd","w3.sd"),info=TRUE)
    
    aggport_model<-summaryBy(w1+w2+w3~occ2,data=test,FUN=c(mean,sd))
    aggport_model$occend <- aggport_model$occ2
    dim(aggport_model)
    aggport_model<-aggport_model[,2:8]
    
    test$inc2 <- test$inc1*(test$incgr+1)	
    
    summary(test$inc1)
    test$ydata <- exp(log(test$inc2/test$inc1)/4)-1 
    test$istay <- ifelse((test$occ1==test$occ2),1,0)
    test$lwinit <- log(test$inc1)
    test$lcredit <- log(test$credits)
    summary(test$ydata)
    
    test$istay.diver <- test$istay*test$diver	
     
    summary(test$istay)
    
    test$istay2<-ifelse((test$occ1==test$occ87)&
                        (test$occ87==test$occ88)&
                        (test$occ88==test$occ89)&
                        (test$occ89==test$occ2),1,0)
    summary(test$istay2)
    test$istay2.diver <- test$istay2*test$diver	
    test$linc2<-log(test$inc2)
    
    
    #---------------------------------------------------------------------------------
    #---INCOME Regression
    #---------------------------------------------------------------------------------
    
    filename <- paste0("_table_",labelvec[i],".txt")
         
    yfm <- lm(log(inc2)~1+ lwinit+lcredit + diver + 
              icareer + dummy(occ2),data=test)  
     
    zmat <-  cbind(coef(summary(yfm))[,1],
                   coef(summary(yfm))[,4],dim(test)[1],summary(yfm)$r.squared)
    write.table(zmat,file=paste0(pathtodir,"model_reg1_",filename),sep=",")
    
    yfm <- lm(log(inc2)~1+ lwinit+lcredit + diver + 
              istay2 + icareer + dummy(occ2),data = test)  
    zmat <-  cbind(coef(summary(yfm))[,1],coef(summary(yfm))[,4],dim(test)[1],summary(yfm)$r.squared)
    write.table(zmat,file=paste0(pathtodir,"model_reg2_",filename),sep=",")
    
    
    yfm <- lm(log(inc2)~1+ lwinit+lcredit + diver + istay2 +
              istay2.diver+ icareer + dummy(occ2),data=test)  
    zmat <-  cbind(coef(summary(yfm))[,1],coef(summary(yfm))[,4],dim(test)[1],summary(yfm)$r.squared)
    write.table(zmat,file=paste0(pathtodir,"model_reg3_",filename),sep=",")
    
    #---------------------------------------------------------------------------------
    #--- PROBIT REGRESSION
    #---------------------------------------------------------------------------------
    
    
    myprobit<- glm(istay2~1+diver+ dummy(occ2), 
                   family=binomial(link="probit"), data=test, na.action=na.pass)
    zmat <- cbind(coef(summary(myprobit))[,1],
                  coef(summary(myprobit))[,4],
                  dim(test)[1],summary(myprobit)$r.squared)
    write.table(zmat,file=paste0(pathtodir,"model_probit1_",filename),sep=",")
    
    
    myprobit<- glm(istay2~1+diver+lwinit+ dummy(occ2), 
                   family=binomial(link="probit"), data=test, na.action=na.pass)
    zmat <- cbind(coef(summary(myprobit))[,1],
                  coef(summary(myprobit))[,4],
                  dim(test)[1],summary(myprobit)$r.squared)
    write.table(zmat,file=paste0(pathtodir,"model_probit2_",filename),sep=",")
    
    
    myprobit<- glm(istay2~1+diver+lwinit+ lcredit+ dummy(occ2),
                   family=binomial(link="probit"), data=test, na.action=na.pass)
    zmat <- cbind(coef(summary(myprobit))[,1],
                  coef(summary(myprobit))[,4],
                  dim(test)[1],summary(myprobit)$r.squared)
    write.table(zmat,file=paste0(pathtodir,"model_probit3_",filename),sep=",")
    
    summary <- as.data.frame(rbind(sd(test$ydata),matrix(summary(test$ydata)),skewness(test$ydata),kurtosis(test$ydata)))
    summary$V2 <- c("SD", "Min","1Q","Med","Mean","3Q","Max","Skew","Kurt")
    
    write.table(summary,file=paste0(pathtodir,"Summary_model_incgrowth_",labelvec[i],".txt"),col.names=F)
    print(table(test$occ1))
    print(table(test$occ2))
    
    #---------------------------------------------------------------------------------
    #--- Inequality and Growth Measures for switchers and non-switchers
    #---------------------------------------------------------------------------------
    
    switchers <- test[test$istay2==0,]
    nonswitchers <- test[test$istay2==1,]
    
    switch_data <- mat.or.vec(19,2)
    switch_data[1,1] <- "Average Log Income - All" 
    switch_data[2,1] <- "Gini Income - All" 
    switch_data[3,1] <- "Average Income Growth - All" 
    switch_data[4,1] <- "Std.Dev. Income Growth - All" 
    switch_data[5,1] <- "p(99)/p(50) - All" 
    
    switch_data[1,2] <- mean(test$linc2)
    switch_data[2,2] <- Gini(test$inc2,corr=F) 
    switch_data[3,2] <- mean(test$ydata)
    switch_data[4,2] <- sd(test$ydata)
    switch_data[5,2] <- quantile(test$inc2,0.99)/quantile(test$inc2,0.50)
    
    switch_data[6,1] <- "Average Log Income - Non Switchers" 
    switch_data[7,1] <- "Gini Income - Non Switchers" 
    switch_data[8,1] <- "Average Income Growth - Non Switchers" 
    switch_data[9,1] <- "Std.Dev. Income Growth - Non Switchers" 
    switch_data[10,1] <- "p(99)/p(50) - Non-Switchers" 
    
    
    switch_data[6,2] <- mean(nonswitchers$linc2)
    switch_data[7,2] <- Gini(nonswitchers$inc2,corr=F)
    switch_data[8,2] <- mean(nonswitchers$ydata)
    switch_data[9,2] <- sd(nonswitchers$ydata)
    switch_data[10,2] <- quantile(nonswitchers$inc2,0.99)/quantile(nonswitchers$inc2,0.50)
    
    
    switch_data[11,1] <- "Average Log Income - Switchers" 
    switch_data[12,1] <- "Gini Income - Switchers" 
    switch_data[13,1] <- "Average Income Growth - Switchers" 
    switch_data[14,1] <- "Std.Dev. Income Growth - Switchers" 
    switch_data[15,1] <- "p(99)/p(50) - Switchers" 
    
    switch_data[16,1] <- "Percentage of Switchers" 
    switch_data[17,1] <- "Cost - All"
    switch_data[18,1] <- "Cost - Non Switchers"
    switch_data[19,1] <- "Cost - Switchers"
    
    switch_data[11,2] <-  mean(switchers$linc2)
    switch_data[12,2]<- Gini(switchers$inc2,corr=F)
    switch_data[13,2] <- mean(switchers$ydata)
    switch_data[14,2] <- sd(switchers$ydata)
    switch_data[15,2] <- quantile(switchers$inc2,0.99)/quantile(switchers$inc2,0.50)
    
    
    switch_data[16,2] <- dim(switchers)[1]/dim(test)[1]
    switch_data[17,2] <- mean(test$cost,na.rm=TRUE)
    switch_data[18,2] <- mean(nonswitchers$cost,na.rm=TRUE)
    switch_data[19,2] <- mean(switchers$cost,na.rm=TRUE)
    
    write.table(as.data.frame(switch_data),file=paste0(pathtodir,"exp_data_",labelvec[i],".txt"))
    print(sd(cbind(log(test$inc1),test$linc2)))
    print(sd(log(test$inc1)))
    print(sd(log(test$inc2)))
    print(mean(log(test$inc1)))
    print(mean(log(test$inc2)))
    
    test$h1 <- test$w1*test$credits
    test$h2 <- test$w2*test$credits
    test$h3 <- test$w3*test$credits
    
    print(sd(log(test$h1)))
    print(sd(log(test$h2)))
    print(sd(log(test$h3)))
    
    print(summaryBy(log(test$inc2)~occ2,data=test,FUN=sd))
    print(summary(test))
    print(sd(test$linc2))
    print(Gini(test$inc2,corr=F))
    print(quantile(test$inc2,0.90)/quantile(test$inc2,0.10))
    print(quantile(test$inc2,0.90)/quantile(test$inc2,0.50))

}

#________________________________________________________________________________________
# Compute standard errors
#________________________________________________________________________________________

weights<-read.table(paste0(pathtofortran,"dataweights.txt"))
estimates <-
    read.table(paste0(pathtofortran,"initguess_weighted.txt"))
jacobian <- read.table(paste0(pathtofortran,"jacobian.txt"))
jacobian <- as.matrix(jacobian, nrow=dim(weights)[1],ncol = dim(estimates)[1])
mweight <- diag(weights$V1)
jac <- jacobian
diagonal <- 1/weights
omega <- diag(diagonal$V1)
Sigma <- solve(t(jac)%*%mweight%*%jac)%*%t(jac)%*%mweight%*%omega%*%mweight%*%jac%*%solve(t(jac)%*%mweight%*%jac)

stderr <- sqrt(diag(Sigma))
write.table(stderr,file=paste0(pathtofortran,"standard_errors.txt"))


