# COMPUTE STATISTICS USED FOR THE STRUCTURAL ESTIMATION
# First eliminate those that have occupations 7 and 8 because they have very few observations.
# Also eliminate Farmers, Laborers and Homemakers.
print(dim(test))
test<-test[(test$relab_occ_91>7)|(test$relab_occ_91<7),]
test<-test[(test$relab_occ_91>8)|(test$relab_occ_91<8),]
print('Eliminating Physician and Legal')
print(dim(test))

# These two files are used to summarize portfolios by occupation and
# in the aggregate (Table 1 in paper)
test_noswitch <- test[test$istay==1,]
portfolios<-summaryBy(w_hum+w_math+w_socsci~relab_occ_91,data=test_noswitch,FUN=c(mean,sd))
write.csv(portfolios, file = paste0(pathtodir,"Numbers_for_Table_1.csv"))

# The following numbers are to calibrate the model.
shares_all_occs <- cbind(test$w_hum,test$w_math,test$w_socsci)
write.csv(cbind(apply(shares_all_occs,2,mean),apply(shares_all_occs,2,sd)),
          file = paste0(pathtodir,"Portfolios_All_Occs.csv"))

# Construct Table to provide summary of a few variables in the paper
# (panel A of Table 2)
mat_for_summary <- mat.or.vec(5,5)
vec_for_summary <- cbind(test$diver,log(test$wage91),test$ydata,test$totcred,test$istay) 
for (i in seq(1,5)){
mat_for_summary[i,] <- c(mean(vec_for_summary[,i]),
                         median(vec_for_summary[,i]),
                         sd(vec_for_summary[,i]),
                         min(vec_for_summary[,i]),
                         max(vec_for_summary[,i]))
}
write.csv(mat_for_summary, file = paste0(pathtodir,"Summary_Selected_Table2.csv"))
test<-test[(test$relab_occ_91>10)|(test$relab_occ_91<10),]
test<-test[(test$occinit>10)|(test$occinit<10),]
test<-test[(test$relab_occ_91>16)|(test$relab_occ_91<16),]
test<-test[(test$occinit>16)|(test$occinit<16),]

print('Final Sample Size for Estimating the Model')
print(dim(test))

# Correlation matrix (Table 2)
vmat<-matrix(c(test$diver_measure,log(test$wage91),
               test$ydata,test$totcred,test$istay),ncol=5)
corrmat<- cor(vmat)
colnames(corrmat)<-c("delta","Log(wage)","Delta Y","CRED","STAY")
rownames(corrmat)<-c("delta","Log(wage)","Delta Y","CRED","STAY")

# Correlation matrix (Table 2)
corrmat_signif<- matrix(rcorr(vmat))

write.csv(corrmat, file = paste0(pathtodir,"Correlations_CorrMat_Table2.csv"))
write.csv(corrmat_signif[3], 
          file = paste0(pathtodir,"Significance_CorrMat_Table2.csv"))

summary <- as.data.frame(rbind(sd(test$ydata),
                               matrix(summary(test$ydata)),
                               skewness(test$ydata),kurtosis(test$ydata)))
summary$V2 <- c("SD", "Min","1Q","Med","Mean","3Q","Max","Skew","Kurt")

write.table(summary,file=paste0(pathtodir,"Summary_data_incgrowth.txt"),col.names=F)


test$nobs<- 1
test$lw91 <- log(test$wage91)
dim(test)
portfolios<-summaryBy(w_hum+w_math+w_socsci~relab_occ_91,data=test,FUN=c(mean,sd))
write.csv(portfolios, file =  paste0(pathtostruct,"Portfolio_moments_struct.csv"))

# standard deviation of log wages in the first year
write.csv(sd(test$lwinit), file = paste0(pathtostruct,"Stdev_initial_log_wage.csv"))
#
nobsbyocc<-summaryBy(nobs~relab_occ_91,data=test,FUN=c(sum))
write.csv(c(nobsbyocc$nobs.sum,dim(test)[1]), 
          file =  paste0(pathtostruct,"Sample_Size_by_Occ.csv"))
#
sdearn91<-summaryBy(lw91~relab_occ_91,data=test,FUN=c(sd))
write.csv(sdearn91, file =  paste0(pathtostruct,"sdearn91.csv"))
portvec <- cbind(test$w_hum,test$w_math,test$w_socsci)
write.csv(cbind(apply(portvec,2,mean),
                apply(portvec,2,sd)), 
          file = paste0(pathtostruct,"Stdevs_Shares_by_Skill.csv"))

test$iswitch1 <- ifelse((test$DEGYEAR<=85)&(test$occinit==test$relab_occ_87)|
(test$DEGYEAR==86)&(test$occinit==test$relab_occ_88)|
(test$DEGYEAR==87)&(test$occinit==test$relab_occ_89)|
(test$DEGYEAR==88)&(test$occinit==test$relab_occ_90),0,1)
#
#test$iswitch1 <- ifelse((test$relab_occ_86==test$relab_occ_87),0,1)
x<-summaryBy(iswitch1~occinit,data=test,FUN=c(sum,mean,var))
x
test$y<-1
xx<-summaryBy(y~occinit,data=test,FUN=sum)
xx
# summary of switchers by occupation

write.csv(x, file =  paste0(pathtostruct,"Percentage_Switches_by_Occ.csv"))

# This section counts the number of individuals who stay for two periods in one 
# occupation and then switch.

test$learn85 <- ifelse((test$DEGYEAR<=85)&(test$occinit==test$relab_occ_87)&(test$relab_occ_87!=test$relab_occ_88),1,0)
test$learn86 <- ifelse((test$DEGYEAR==86)&(test$occinit==test$relab_occ_88)&(test$relab_occ_88!=test$relab_occ_89),1,0)
test$learn87 <- ifelse((test$DEGYEAR==87)&(test$occinit==test$relab_occ_89)&(test$relab_occ_89!=test$relab_occ_90),1,0)
test$learn88 <- ifelse((test$DEGYEAR==88)&(test$occinit==test$relab_occ_90)&(test$relab_occ_90!=test$relab_occ_91),1,0)
#
tt<-test$learn85+test$learn86+test$learn87+test$learn88
mean(tt)
# Stay switch events to identify learning probability parameter.
write.csv(c(apply(matrix(tt),2,mean),apply(matrix(tt),2,sd)),file = paste0(pathtostruct,"Stay_Switch_Fraction.csv"))
# Correlation among (log) credits of different skill types.
write.csv(c(cor(log(test$socsci_cred),log(test$math_cred)),cor(log(test$socsci_cred),log(test$hum_cred)),cor(log(test$hum_cred),log(test$math_cred))),file
          = paste0(pathtostruct,"Correlations_of_Amount_of_Credits.csv"))

test$iswitch <- 1-test$istay
write.csv(cbind(mean(test$iswitch),sd(test$iswitch)),file=paste0(pathtostruct,"overall_switching_rate.csv"))
sdcredbyocc<-summaryBy(test$lcredit~relab_occ_91,data=test,FUN=sd)
write.csv(sdcredbyocc,file=paste0(pathtostruct,"sdcredbyocc.csv"))

